import React, { useEffect, useState } from "react";
import PropTypes from "prop-types";
import Tabs from "@mui/material/Tabs";
import Tab from "@mui/material/Tab";
import Typography from "@mui/material/Typography";
import Box from "@mui/material/Box";
import CardCourses from "./CardCourses";
import { getKeywordsCourses } from "../utils";

function TabPanel(props) {
  const { children, value, index, ...other } = props;
  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`vertical-tabpanel-${index}`}
      aria-labelledby={`vertical-tab-${index}`}
      {...other}
    >
      {value === index && (
        <Box sx={{ pl: 3 }}>
          <Typography
            variant="h6"
            style={{ marginBottom: 20, color: "#22436E", fontWeight: "bold" }}
          >
            {children}
          </Typography>
          <Box>
            {props.courses
              ? props.courses.map((myObj) => (
                  <>
                    {myObj.courseTitle ? (
                      <CardCourses
                        device="desktop"
                        joinFree={props?.joinFree}
                        token={props?.token}
                        objCourse={myObj}
                        newUser={props?.newUser}
                        accountDetails={props?.accountDetails}
                      />
                    ) : null}
                  </>
                ))
              : null}
          </Box>
        </Box>
      )}
    </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.number.isRequired,
  value: PropTypes.number.isRequired,
};

function a11yProps(index) {
  return {
    id: `vertical-tab-${index}`,
    "aria-controls": `vertical-tabpanel-${index}`,
  };
}

export default function VerticalTabs(props) {
  const [value, setValue] = useState(
    props.data?.findIndex((object) => {
      const url = props?.slug?.toLowerCase()?.split("-");
      const length = url?.length > 1;
      return (
        object?.categoryName?.toLowerCase() ===
        (length ? url?.join(" ") : url[0])
      );
    })
  );

  const findId = () => {
    const id = props.data?.findIndex((object) => {
      const url = props?.slug?.toLowerCase()?.split("-");
      const length = url?.length > 1;
      return (
        object?.categoryName?.toLowerCase() ===
        (length ? url?.join(" ") : url[0])
      );
    });
    props?.setPageCourseList(props?.data[id]?.coursesList);
    props.selectCourseCategory(id);
    return id;
  };

  const handleChange = (event, newValue) => {
    event.preventDefault();
    props.selectCourseCategory(newValue);
    const url = props.data[newValue].categoryName?.toLowerCase()?.split(" ");
    window.history.replaceState(
      null,
      "",
      `/courses/${url?.length > 1 ? url?.join("-") : url[0]}`
    );
    props?.setPageSlug(url?.length > 1 ? url?.join("-") : url[0]);
    props?.setPageCourseList(props?.data[newValue]?.coursesList);
    props?.setPageTitle(props.data[newValue].categoryName);
    props?.keywords(getKeywordsCourses(props?.data[newValue]?.coursesList));
    setValue(newValue);
  };

  return (
    <Box
      sx={{
        flexGrow: 1,
        bgcolor: "#eff3f6",
        display: "flex",
        minHeight: 700,
        marginLeft: 2,
        marginTop: 6,
        marginBottom: 10,
      }}
    >
      <Tabs
        initialSelectedIndex={findId()}
        orientation="vertical"
        variant="scrollable"
        value={value}
        onChange={handleChange}
        aria-label="Vertical tabs example"
        sx={{ borderRight: 1, borderColor: "divider", minWidth: 195 }}
        TabIndicatorProps={{
          style: { background: "#ffd25d", fontWeight: "bold" },
        }}
        centered={false}
      >
        {props.data
          ? props.data.map((myObj, index) => (
              <Tab
                variant="course_options"
                label={myObj.categoryName}
                {...a11yProps(index)}
                style={{
                  justifyContent: "center !important",
                  paddingLeft: "5px",
                }}
              />
            ))
          : null}
      </Tabs>
      {props.data
        ? props.data.map((myObj, index) => (
            <TabPanel
              accountDetails={props?.accountDetails}
              joinFree={props?.joinFree}
              courses={myObj.coursesList}
              token={props?.token}
              newUser={props.newUser}
              value={value}
              index={index}
            >
              {myObj.categoryName}
            </TabPanel>
          ))
        : null}
    </Box>
  );
}
