import React, { useState, useEffect } from "react";
import PropTypes from "prop-types";
import Tabs from "@mui/material/Tabs";
import Tab from "@mui/material/Tab";
import Typography from "@mui/material/Typography";
import Box from "@mui/material/Box";
import CardCourses from "./CardCourses";
import { Grid } from "@material-ui/core";
import { getKeywordsCourses } from "../utils";

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`vertical-tabpanel-${index}`}
      aria-labelledby={`vertical-tab-${index}`}
      {...other}
    >
      {value === index && (
        <Box>
          <Typography
            variant="h6"
            style={{
              marginTop: 30,
              marginBottom: 10,
              color: "#22436E",
              fontWeight: "bold",
            }}
          >
            {children}
          </Typography>
          <Grid container>
            <Grid item md={12} sm={12} xs={12}>
              {props.courses
                ? props.courses.map((myObj) => (
                    <>
                      {myObj.courseTitle ? (
                        <CardCourses
                          device="mobile"
                          joinFree={props?.joinFree}
                          token={props?.token}
                          newUser={props.newUser}
                          objCourse={myObj}
                          accountDetails={props?.accountDetails}
                        />
                      ) : null}
                    </>
                  ))
                : null}
            </Grid>
          </Grid>
        </Box>
      )}
    </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.number.isRequired,
  value: PropTypes.number.isRequired,
};

export default function VerticalTabs(props) {
  const [value, setValue] = useState(
    props.data?.findIndex((object) => {
      const url = props?.slug?.toLowerCase()?.split("-");
      const length = url?.length > 1;
      return (
        object?.categoryName?.toLowerCase() ===
        (length ? url?.join(" ") : url[0])
      );
    })
  );
  const [nextUrl, setNextUrl] = useState("");

  const findId = () => {
    const id = props.data?.findIndex((object) => {
      const url = props?.slug?.toLowerCase()?.split("-");
      const length = url?.length > 1;
      return (
        object?.categoryName?.toLowerCase() ===
        (length ? url?.join(" ") : url[0])
      );
    });
    props?.setPageCourseList(props?.data[id]?.coursesList);
    props.selectCourseCategory(id);
    return id;
  };

  const handleChange = (event, newValue) => {
    props.selectCourseCategory(newValue);
    const url = props.data[newValue].categoryName?.toLowerCase()?.split(" ");
    setNextUrl(url);
    window.history.replaceState(
      null,
      "",
      `/courses/${url?.length > 1 ? url?.join("-") : url[0]}`
    );
    props?.setPageSlug(url?.length > 1 ? url?.join("-") : url[0]);
    props?.setPageCourseList(props?.data[newValue]?.coursesList);
    props?.setPageTitle(props.data[newValue].categoryName);
    props?.keywords(getKeywordsCourses(props?.data[newValue]?.coursesList));
    setValue(newValue);
  };

  return (
    <Box sx={{ bgcolor: "#eff3f6", marginTop: 2, marginBottom: 10 }}>
      <Tabs
        initialSelectedIndex={findId()}
        variant="scrollable"
        value={value}
        onChange={handleChange}
        aria-label="Vertical tabs example"
        scrollButtons="auto"
        centered={false}
        TabIndicatorProps={{ hidden: true }}
        sx={{
          "& button": {
            alignItems: "center !important",
            minHeight: "35px !important",
            paddingLeft: 1,
            paddingRight: 1,
            marginRight: 1,
            paddingTop: 1,
            borderRadius: 2,
            borderWidth: 1,
            borderColor: "#CCC",
            borderStyle: "solid",
          },
          "& button:hover": { backgroundColor: "#fff" },
          "& button.Mui-selected": {
            backgroundColor: "#ffd25d",
            borderWidth: 1,
            borderColor: "#CCC",
            borderStyle: "solid",
          },
          "& svg": { fontSize: "2rem", marginTop: 1 },
        }}
      >
        {props.data
          ? props.data.map((myObj, index) => (
              <Tab key={index} label={myObj.categoryName} />
            ))
          : null}
      </Tabs>
      {props.data
        ? props.data.map((myObj, index) => (
            <TabPanel
              joinFree={props?.joinFree}
              courses={myObj.coursesList}
              accountDetails={props?.accountDetails}
              value={value}
              token={props?.token}
              newUser={props.newUser}
              key={index}
              index={index}
            >
              {myObj.categoryName}
            </TabPanel>
          ))
        : null}
    </Box>
  );
}
