import React, { useEffect, useState } from "react";
import OtpInput from "react-otp-input";
import axios from "axios";

// Styles
import styles from "./OtpInputs.module.css";

const OtpInputs = (props) => {
  const [count, setCount] = useState(60);

  const handleCount = async () => {
    try {
      const url = process.env.NEXT_PUBLIC_API_URL + "/signup-resendotp";
      const getToken = await axios.post(url, null, {
        params: {
          token: props?.token,
        },
      });
      props?.setIsError(false)
      props?.setOtpNumber("")
      setCount(60);
    } catch (err) {
      console.log(err);
    }
  };

  useEffect(() => {
    if (count > 0) {
      const countTimeout = setTimeout(() => {
        setCount(count - 1);
      }, 1000);

      return (() => {
        clearTimeout(countTimeout)
      })
    }
  }, [count]);

  return (
    <div className={styles.otp_inputs}>
      <div className={`flex_display ${styles.mobile_number}`}>
        <span className={`flex_display ${styles.modal_region_code}`}>
          <img src="/india.png" width={18} height={18} /> <span>+91</span>
        </span>
        <input
          type="text"
          className={`${styles.modal_number_input}`}
          value={props?.mobile}
          onChange={props?.handleNumberChange}
          maxLength="10"
          readOnly={true}
        />
        <span
          className={`flex_display ${styles.modal_region_code}`}
          onClick={() => {
            props?.setIsError(false)
            props?.setStep(0);
          }}
        >
          <span>Edit</span>
        </span>
      </div>

      <label className={`${styles.modal_label}`}>
        Please check your mobile for OTP. {props?.isError ? <span style={{color: "#ff0000"}}>Invalid OTP</span> : <></>}
      </label>

      <OtpInput
        value={props?.otpNumber}
        onChange={props?.setOtpNumber}
        shouldAutoFocus={true}
        numInputs={6}
        renderSeparator={<span> </span>}
        containerStyle={styles.otp_container}
        inputStyle={`${styles.otp_inputStyle} ${props?.isError ? styles.otp_error : ""}`}
        inputType="number"
        renderInput={(props) => <input {...props} />}
      />

      <div>
        {count === 0 ? (
          <span
            className={`${styles.modal_label}`}
            style={{ cursor: "pointer" }}
            onClick={handleCount}
          >
            Resend OTP
          </span>
        ) : (
          <span className={`${styles.modal_label}`}>Resend OTP</span>
        )}{" "}
        {count > 0 ? (
          <span className={`${styles.modal_label}`}>in {count}</span>
        ) : (
          <></>
        )}
      </div>
    </div>
  );
};

export default OtpInputs;
