import React, { useEffect, useState, useRef } from "react";
import ReactDOM from "react-dom";
import Cookies from "js-cookie";
// import { useSession, signIn, signOut } from "next-auth/react";
import axios from "axios";

// Styles
import styles from "./RegisterModal.module.css";

// Component
import AboutYou from "./AboutYou/AboutYou";
import OtpInputs from "./OtpInputs/OtpInputs";
import MobileInput from "./MobileInput/MobileInput";
import RegisterButton from "./RegisterButton/RegisterButton";

const RegisterModal = (props) => {
  // const { data, status } = useSession();

  // if (status === "authenticated") {

  // }

  // States
  const [step, setStep] = useState(0);
  const [name, setName] = useState("");
  const [token, setToken] = useState("");
  const [mobile, setMobile] = useState("");
  const [loader, setLoader] = useState(true);
  const [isError, setIsError] = useState(false);
  const [otpNumber, setOtpNumber] = useState("");

  // Refs
  const wrapperRef = useRef(null);
  useOutsideAlerter(wrapperRef);

  // Utility Functions
  const handleNumberChange = (e) => {
    const pattern = new RegExp(/^\d{1,10}$/);
    setMobile(e.target.value);
    if (!pattern.test(e.target.value) || e.target.value?.length < 10)
      setIsError(true);
    else setIsError(false);
  };

  // Handle Number
  const handleNumberHome = async (number) => {
    try {
      const url = process.env.NEXT_PUBLIC_API_URL + "/signup-sendotp";
      const getToken = await axios.post(url, null, {
        params: {
          mobile: number,
        },
      });
      if (getToken?.data?.responseTxt === "failed") {
        setLoader(false);
        return;
      } else {
        setToken(getToken?.data?.obj?.token);
        setStep(step + 1);
        setLoader(false);
      }
    } catch (err) {
      setLoader(false);
      console.log(err);
    }
  };

  // Handle Number
  const handleNumber = async () => {
    try {
      const url = process.env.NEXT_PUBLIC_API_URL + "/signup-sendotp";
      const getToken = await axios.post(url, null, {
        params: {
          mobile,
        },
      });

      if (getToken?.data?.responseTxt === "failed") {
        return;
      } else {
        setToken(getToken?.data?.obj?.token);
        setStep(step + 1);
      }
    } catch (err) {
      console.log(err);
    }
  };

  // detect outside click
  function useOutsideAlerter(ref) {
    useEffect(() => {
      /**
       * Alert if clicked on outside of element
       */
      function handleClickOutside(event) {
        if (ref.current && !ref.current.contains(event.target)) {
          props?.setRegisterPopup(false);
        }
      }
      // Bind the event listener
      document.addEventListener("mousedown", handleClickOutside);
      return () => {
        // Unbind the event listener on clean up
        document.removeEventListener("mousedown", handleClickOutside);
      };
    }, [ref]);
  }

  // Handle OTP
  const handleOtp = async () => {
    try {
      const url = process.env.NEXT_PUBLIC_API_URL + "/signup-verifyotp";
      const getToken = await axios.post(url, null, {
        params: {
          otpNumber,
          token,
        },
      });
      if (getToken?.data?.responseTxt === "invalid_otp") {
        setIsError(true);
        return;
      } else if (getToken?.data?.responseTxt === "old_student") {
        Cookies.set(
          "accountDetails",
          JSON.stringify({ ...getToken?.data?.obj, mobile })
        );
        Cookies.set("new_user", false);
        Cookies.set("token", JSON.stringify(getToken?.data?.obj?.token));
        window.location.href =
          process.env.NEXT_PUBLIC_LOGIN_URL +
          "/logindirect?loginKey=" +
          getToken?.data?.obj?.token;
      } else {
        Cookies.set(
          "accountDetails",
          JSON.stringify({ ...getToken?.data?.obj, mobile })
        );
        Cookies.set("token", JSON.stringify(getToken?.data?.obj?.token));
        Cookies.set("new_user", true);
        setToken(getToken?.data?.obj?.token);
        setStep(step + 1);
      }
    } catch (err) {
      console.log(err);
    }
  };

  const handleName = async () => {
    try {
      const url =
        process.env.NEXT_PUBLIC_API_URL + "/signup-update-student-name";
      const getToken = await axios.post(url, null, {
        params: {
          studentName: name,
          token,
        },
      });
      if (getToken?.data?.responseTxt === "student_updated") {
        setIsError(false);
        Cookies.set(
          "accountDetails",
          JSON.stringify({
            ...JSON.parse(Cookies.get("accountDetails")),
            studentName: name,
          })
        );

        if (props?.status === "course" && Cookies.get("courseDetails")) {
          window.location.href = "/create-account-process";
        } else {
          window.location.href = "/courses/engineering";
        }
      }
    } catch (err) {
      console.log(err);
    }
  };

  // UseEffects
  useEffect(() => {
    if (props?.home) {
      setMobile(props?.home);
      handleNumberHome(props?.home);
    } else {
      setLoader(false);
    }
  }, []);

  const modal = loader ? (
    <></>
  ) : (
    <div className={`${styles.modal_overlay}`}>
      <div ref={wrapperRef} className={`flex_display ${styles.register_modal}`}>
        <div className={`flex_display ${styles.modal_left}`}>
          <div className={`${styles.modal_left_container}`}>
            <img
              className={`${styles.modal_left_img}`}
              src={"/tony.png"}
              width={148}
              height={148}
            />
            <h2>Meet your AI Co-teacher TONY!</h2>
            <p>
              Learn it, Master it, Love It: Unmilited Learning Session with Tony
              your AI co-teacher
            </p>
          </div>
        </div>
        <div className={`${styles.modal_right}`}>
          <span
            onClick={() => props?.setRegisterPopup(false)}
            className={`${styles.modal_right_cross}`}
          >
            &#10005;
          </span>
          {step === 0 ? (
            <>
              <h2 className={`${styles.modal_heading}`}>
                {props?.status === "login" ? "Log in" : "Get Started"}
              </h2>
              <MobileInput
                isError={isError}
                mobile={mobile}
                handleNumberChange={handleNumberChange}
                step={step}
                setStep={setStep}
              />
              <RegisterButton onClick={handleNumber} text="Get OTP" />

              {/* {status === "authenticated" ? (
                <button
                  onClick={(e) => {
                    e.preventDefault();
                    signOut("google");
                  }}
                >
                  Sign out
                </button>
              ) : (
                <button
                  onClick={(e) => {
                    e.preventDefault();
                    signIn("google", {
                      callbackUrl:
                        process.env.NEXT_PUBLIC_FRONTEND_URL +
                        "/api/auth/callback/google",
                    });
                  }}
                >
                  Sign in with google
                </button>
              )} */}
            </>
          ) : (
            <></>
          )}

          {step === 1 ? (
            <>
              <h2 className={`${styles.modal_heading}`}>Verify OTP</h2>
              <OtpInputs
                isError={isError}
                setIsError={setIsError}
                mobile={mobile}
                handleNumberChange={handleNumberChange}
                otpNumber={otpNumber}
                token={token}
                step={step}
                setStep={setStep}
                setOtpNumber={setOtpNumber}
              />
              <RegisterButton onClick={handleOtp} text="Verify OTP" />
            </>
          ) : (
            <></>
          )}

          {step === 2 ? (
            <>
              <h2 className={`${styles.modal_heading}`}>About You</h2>
              <AboutYou
                isError={isError}
                mobile={mobile}
                handleNumberChange={handleNumberChange}
                otpNumber={otpNumber}
                name={name}
                setName={setName}
                step={step}
                setStep={setStep}
                setOtpNumber={setOtpNumber}
              />
              <RegisterButton onClick={handleName} text="Continue" />
            </>
          ) : (
            <></>
          )}
          <p className={`${styles.modal_signup}`}>
            {props?.status === "login"
              ? "Don't have an account?"
              : "Already have an account? "}{" "}
            <span
              style={{ cursor: "pointer", fontWeight: "800" }}
              onClick={() =>
                props?.setStatus(props?.status === "login" ? "signup" : "login")
              }
            >
              {props?.status === "login" ? "Sign Up" : "Login"}
            </span>
          </p>
        </div>
      </div>
    </div>
  );

  return ReactDOM.createPortal(modal, document.getElementById("modal-root"));
};

export default RegisterModal;
