import React from 'react';
import PropTypes from 'prop-types';
import { makeStyles } from '@material-ui/core/styles';
import { AppBar, Tabs, Tab, Box, Link} from '@material-ui/core';

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
        <div
          role="tabpanel"
          hidden={value !== index}
          id={`scrollable-auto-tabpanel-${index}`}
          aria-labelledby={`scrollable-auto-tab-${index}`}
          {...other}
        >
          {value === index && (
            <Box mt={2}>
              <h4 style={{textAlign:'center'}} >{children}</h4>
            </Box>
          )}
        </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired,
};

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
    width: '100%',
  },
}));

export default function ScrollableTabsButtonAuto() {
  const classes = useStyles();

  return (
    <div className="homeCategoryTabBox">
    <div className={classes.root}>
      <AppBar position="static" color="white" style={{boxShadow:'none',boxSizing:'none'}} > 
        <Tabs
          indicatorColor="primary"
          textColor="primary"
          variant="scrollable"
          scrollButtons="auto"
          aria-label="scrollable auto tabs example"
        >
          {['Bank Clerk','Bank PO','Bank SO','Defence','Engineering','Insurance','Law','Management','MCA','Medical','Nabard','NIFT','Railways','RBI','SSC','State PCS','UPSE'].map( (myCourse, i) =>(
              <Tab key={'taba'+i} label={
                  <Link href="#" >
                    <Box m={1} className='category-box' >                      
                      <span>{myCourse}</span>                    
                    </Box>
                  </Link>                
                  }
              />
          ))}        

        </Tabs>
      </AppBar>

    </div>

    </div>
  );
}
