import React from 'react';
import PropTypes from 'prop-types';
import { makeStyles } from '@material-ui/core/styles';
import { AppBar, Tabs, Tab, Box, Link} from '@material-ui/core';

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
        <div
          role="tabpanel"
          hidden={value !== index}
          id={`scrollable-auto-tabpanel-${index}`}
          aria-labelledby={`scrollable-auto-tab-${index}`}
          {...other}
        >
          {value === index && (
            <Box mt={2}>
              <h4 style={{textAlign:'center'}} >{children}</h4>
            </Box>
          )}
        </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired,
};

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
    width: '100%',
  },
}));

export default function ScrollableTabsButtonAuto() {
  const classes = useStyles();

  return (
    <div className={classes.root}>
      <AppBar position="static" style={{backgroundColor: '#eff3f6',boxShadow:'none',boxSizing:'none'}} > 
        <Tabs
          indicatorColor="primary"
          textColor="primary"
          variant="scrollable"
          scrollButtons="auto"
          aria-label="scrollable" 
          style={{alignSelf:'center'}}
        >
              <Tab className='blogTab' label={
                  <div className="blogbox">
                      <img loading="lazy" alt="library with books blog ETL"  src="/blog-new.webp" width="100%" />
                      <p className="color-dark">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Tellus magna odio lorem nec nulla non velit ipsum sit.
                      </p>
                      <a href="#" className="btn sellerbt ">Read more</a>
                  </div>
                }
              />
              <Tab className='blogTab' label={
                  <div className="blogbox">
                      <img loading="lazy" alt="girl wearing headphones ETL" src="/headphone-girl.webp" width="100%" />
                      <p className="color-dark">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Tellus magna odio lorem nec nulla non velit ipsum sit.
                      </p>
                      <a href="#" className="btn sellerbt ">Read more</a>
                  </div>
                }
              />
              <Tab className='blogTab' label={
                  <div className="blogbox">
                      <img loading="lazy" alt="analytics ETL" src="/anlatics.webp" width="100%" />
                      <p className="color-dark">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Tellus magna odio lorem nec nulla non velit ipsum sit.
                      </p>
                      <a href="#" className="btn sellerbt ">Read more</a>
                  </div>
                }
              />

        </Tabs>
      </AppBar>

    </div>

  );
}
