import React from "react";
import Head from "next/head";
//import Image from 'next/image';
//import fetch from 'isomorphic-unfetch';
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import CircularProgress from "@mui/material/CircularProgress";
import Header from "../components/Header";
import Footer from "../components/Footer";
import FormHelperText from "@mui/material/FormHelperText";
import axios from "axios";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  //const cityListing = useSelector(state => state.cityListing);
  //const myCity = (cityListing.map(city => (city.name))).toString().toLowerCase();
  const classes = useStyles();

  const [waitBtn, setWaitBtn] = React.useState(false);

  const [fullName, setFullName] = React.useState("");
  const [email, setEmail] = React.useState("");
  const [mobile, setMobile] = React.useState("");
  const [subject, setSubject] = React.useState("");
  const [message, setMessage] = React.useState("");

  const [emailValMsg, setEmailValMsg] = React.useState("Enter your email");
  const [mobileValMsg, setMobileValMsg] = React.useState(
    "Enter your mobile number"
  );

  const [formMessage, setFormMessage] = React.useState("");

  const [fullNameVal, setFullNameVal] = React.useState(false);
  const [emailVal, setEmailVal] = React.useState(false);
  const [mobileVal, setMobileVal] = React.useState(false);
  const [subjectVal, setSubjectVal] = React.useState(false);
  const [messageVal, setMessageVal] = React.useState(false);

  const validateEmail = (email) => {
    return String(email)
      .toLowerCase()
      .match(
        /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
      );
  };

  function submit() {
    if (!fullName) {
      setFullNameVal(true);
    } else {
      setFullNameVal(false);
    }
    if (!email) {
      setEmailValMsg("Enter your email");
      setEmailVal(true);
    } else {
      setEmailVal(false);
    }
    if (email && email.length > 0 && !validateEmail(email)) {
      setEmailVal(true);
      setEmailValMsg("Email is not valid.");
      return false;
    }
    if (!mobile) {
      setMobileValMsg("Enter your mobile number");
      setMobileVal(true);
    } else if (mobile && mobile.length < 10) {
      setMobileValMsg("Enter valid mobile number");
      setMobileVal(true);
    } else {
      setMobileVal(false);
    }
    if (!subject) {
      setSubjectVal(true);
    } else {
      setSubjectVal(false);
    }
    if (!message) {
      setMessageVal(true);
      return false;
    } else {
      setMessageVal(false);
    }

    if (mobile && fullName) {
      setWaitBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("fullName", fullName);
      data.append("email", email);
      data.append("mobile", mobile);
      data.append("subject", subject);
      data.append("message", message);

      axios
        .post(process.env.NEXT_PUBLIC_API_URL + "/website-contactusform", data, axiosHeader)
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "success") {
            setFormMessage("Your message has been sent successfully.");
            return false;
          } else {
            setFormMessage("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setFormMessage("" + error);
          return false;
        });
    }
  }

  function onEnter(event) {
    if (event.key === "Enter") {
      submit();
    }
  }

  function numberOnly(event) {
    if (!/[0-9]/.test(event.key)) {
      event.preventDefault();
    }
  }

  function handleFullName(val) {
    setFullName(val);
    if (val) {
      setFullNameVal(false);
    } else {
      setFullNameVal(true);
    }
  }

  function handleEmail(val) {
    setEmail(val);
    if (val) {
      setEmailVal(false);
      if (val && val.length > 0 && !validateEmail(val)) {
        setEmailVal(true);
        setEmailValMsg("Email is not valid");
      }
    } else {
      setEmailValMsg("Enter your email");
      setEmailVal(true);
    }
  }

  function handleMobile(val) {
    setMobile(val);
    if (val) {
      setMobileVal(false);
      if (val && val.length < 10) {
        setMobileValMsg("Enter valid mobile number");
        setMobileVal(true);
      }
    } else {
      setMobileValMsg("Enter mobile number");
      setMobileVal(true);
    }
  }

  function handleSubject(val) {
    setSubject(val);
    if (val) {
      setSubjectVal(false);
      if (val && val.length < 5) {
        setSubjectVal(true);
      }
    } else {
      setSubjectVal(true);
    }
  }

  function handleMessage(val) {
    setMessage(val);
    if (val) {
      setMessageVal(false);
      if (val && val.length < 50) {
        setMessageVal(true);
      }
    } else {
      setMessageVal(true);
    }
  }

  return (
    <>
      <Head>
        <title>Contact Us - EaseToLearn | Website & APP</title>
        <meta
          name="description"
          content="Contact Us to Get in Touch for Any Enquiry, Business Enquiry or Enquiry For Couselling- EaseToLearn"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <section className="mycontainer " style={{ marginTop: 30 }}>
            <div className="barbox-head color-dark">
              <h2 className="fixhead">Let's Connect!</h2>
              <div className="bar bg-dark"></div>
            </div>
          </section>

          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img
                  loading="lazy"
                  alt="people holding hands in unity"
                  src="/contactus.webp"
                />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <Grid className="frmbx" style={{ marginTop: -3 }}>
                  <Grid container spacing={1}>
                    {formMessage ? (
                      <Grid item md={12} sm={12} xs={12}>
                        <center
                          style={{
                            fontSize: 15,
                            fontWeight: "bold",
                            color: "#0000FF",
                            marginTop: 30,
                            marginBottom: 30,
                          }}
                        >
                          {formMessage}
                        </center>
                      </Grid>
                    ) : (
                      <>
                        <Grid item md={12} sm={12} xs={12}>
                          Name
                          <TextField
                            onChange={(event) =>
                              handleFullName(event.target.value)
                            }
                            value={fullName}
                            onKeyPress={(event) => {
                              onEnter(event);
                            }}
                            fullWidth
                            variant="outlined"
                          />
                          {fullNameVal ? (
                            <FormHelperText>Enter your name</FormHelperText>
                          ) : null}
                        </Grid>
                        <Grid item md={12} sm={12} xs={12}>
                          Email
                          <TextField
                            onChange={(event) =>
                              handleEmail(event.target.value)
                            }
                            value={email}
                            onKeyPress={(event) => {
                              onEnter(event);
                            }}
                            fullWidth
                            variant="outlined"
                          />
                          {emailVal ? (
                            <FormHelperText>{emailValMsg}</FormHelperText>
                          ) : null}
                        </Grid>
                        <Grid item md={12} sm={12} xs={12}>
                          Mobile
                          <TextField
                            onChange={(event) =>
                              handleMobile(event.target.value)
                            }
                            value={mobile}
                            onKeyPress={(event) => {
                              numberOnly(event);
                            }}
                            inputProps={{ maxlength: 10 }}
                            fullWidth
                            variant="outlined"
                          />
                          {mobileVal ? (
                            <FormHelperText>{mobileValMsg}</FormHelperText>
                          ) : null}
                        </Grid>
                        <Grid item md={12} sm={12} xs={12}>
                          Subject
                          <TextField
                            onChange={(event) =>
                              handleSubject(event.target.value)
                            }
                            value={subject}
                            onKeyPress={(event) => {
                              onEnter(event);
                            }}
                            fullWidth
                            variant="outlined"
                          />
                          {subjectVal ? (
                            <FormHelperText>Enter subject</FormHelperText>
                          ) : null}
                        </Grid>
                        <Grid item md={12} sm={12} xs={12}>
                          Message
                          <TextField
                            onChange={(event) =>
                              handleMessage(event.target.value)
                            }
                            value={message}
                            onKeyPress={(event) => {
                              onEnter(event);
                            }}
                            fullWidth
                            variant="outlined"
                            multiline
                            rows={4}
                          />
                          {messageVal ? (
                            <FormHelperText>Enter message</FormHelperText>
                          ) : null}
                        </Grid>
                        <Grid item md={12} sm={12} xs={12}>
                          <div className="paybtnbox">
                            {waitBtn ? (
                              <a className="paybtnwait">
                                <CircularProgress size={13} color={"inherit"} />
                                Wait...
                              </a>
                            ) : (
                              <a
                                href="javscript:;"
                                onClick={() => {
                                  submit();
                                }}
                                className="paybtn"
                              >
                                Submit
                              </a>
                            )}
                          </div>
                        </Grid>
                      </>
                    )}
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <div className="margin-bottommin-res"></div>

        <Footer />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
