import React, { useEffect, useState } from "react";
import Head from "next/head";
import { useRouter } from "next/router";
import { styled } from "@mui/material/styles";
import Typography from "@mui/material/Typography";
import CheckIcon from "@mui/icons-material/Check";
import CircularProgress from "@mui/material/CircularProgress";
import Rating from "@mui/material/Rating";
import Avatar from "@mui/material/Avatar";
import LinearProgress, {
  linearProgressClasses,
} from "@mui/material/LinearProgress";
import StarIcon from "@mui/icons-material/Star";
import { Box, Grid, TextField } from "@material-ui/core";
import LocalOfferIcon from "@mui/icons-material/LocalOffer";
import RelatedCourses from "../../components/RelatedCourses";
import CourseDetailDesktop from "../../components/CourseDetailDesktop";
import Cookies from "js-cookie";
import axios from "axios";
import Link from "next/link";
import Layout from "../../client/Layout";
import Favicon from "../../client/Favicon";
import Schema from "../../client/Schema";

// CSS
import styles from "./Course.module.css";
import RegisterModal from "../../components/RegisterModal/RegisterModal";

const BorderLinearProgress = styled(LinearProgress)(({ theme }) => ({
  height: 10,
  borderRadius: 5,
  [`&.${linearProgressClasses.colorPrimary}`]: {
    backgroundColor:
      theme.palette.grey[theme.palette.mode === "light" ? 200 : 800],
  },
  [`& .${linearProgressClasses.bar}`]: {
    borderRadius: 5,
    backgroundColor: theme.palette.mode === "light" ? "#1a90ff" : "#308fe8",
  },
}));

const CssTextField = styled(TextField)({
  "& .MuiInputBase-root": {
    color: "white",
  },
  "& .MuiInput-underline:after": {
    borderBottomColor: "#f7ce23",
  },
  "& .MuiOutlinedInput-root": {
    "& fieldset": {
      borderColor: "white",
    },
    "&:hover fieldset": {
      borderColor: "#24f43c",
    },
    "&.Mui-focused fieldset": {
      borderColor: "#f7ce23",
    },
  },
});

export default function Home(props) {
  const [payableAmount, setPayableAmount] = useState(0);
  const [alertMessage, setAlertMessage] = useState("");
  const [severityAlert, setSeverityAlert] = useState("error");
  const [code, setCode] = useState("");
  const [appliedPromoCode, setAppliedPromoCode] = useState("");
  const [applyPromoCodeLoading, setApplyPromoCodeLoading] = useState(false);
  const [applyPromoCodeDone, setApplyPromoCodeDone] = useState(false);
  const [reviews, setReviews] = useState([]);
  const [page, setPage] = useState(1);
  const [tabIndex, setTabIndex] = useState(0);
  const [tabObj, setTabObj] = useState(props?.tabData?.obj);
  const [priceList, setPriceList] = useState([]);
  const [selectedPack, setSelectedPack] = useState(0);
  const [register, setRegister] = useState(false);
  const [status, setStatus] = useState("course");

  const packSelected = {
    border: "2px solid #fc5902",
    borderRadius: 10,
    backgroundColor: "#FFF",
    // margin: 20,
    marginTop: 30,
    padding: 10,
    width: "100%",
  };
  const packNonSelected = {
    border: "1px solid #FFF",
    borderRadius: 10,
    // margin: 20,
    marginTop: 30,
    padding: 10,
    color: "#FFF",
    width: "100%",
  };

  const rowPerPage = 25;
  const [totalRecords, setTotalRecords] = useState(rowPerPage);
  const router = useRouter();
  const courseArr = router.query.params || [];

  function handleSelectedPack(i) {
    setSelectedPack(i);
    setPayableAmount(priceList[i].salePrice);
  }

  useEffect(() => {
    getTabIndex();
    if (
      props.data &&
      props.data.obj &&
      props.data.obj.ratingReviewsObj &&
      props.data.obj.ratingReviewsObj.reviews &&
      props.data.obj.ratingReviewsObj.reviews.length > 0
    ) {
      setReviews(props.data.obj.ratingReviewsObj.reviews);
    }
  }, [props.data]);

  function moreReviews() {
    setTotalRecords(rowPerPage + page * rowPerPage);
    setPage(page + 1);
    getApiMoreReviews(page);
  }

  async function getApiMoreReviews(page) {
    let axiosHeader = {
      headers: {
        "Content-Type": "multipart/mixed",
      },
    };
    let apiURL =
      process.env.NEXT_PUBLIC_API_URL +
      "/website-ratings?courseId=" +
      props.data.obj.courseId +
      "&page=" +
      page;
    axios.get(apiURL, axiosHeader).then((response) => {
      if (
        response &&
        response.data &&
        response.data.responseTxt === "success"
      ) {
        const newList = reviews.concat(response.data.list);
        setReviews(newList);
        return false;
      } else {
        setSeverityAlert("error");
        setAlertMessage("Something wrong somewhere");
        return false;
      }
    });
  }

  function selectThisCourse(styp) {
    Cookies.set(
      "courseDetails",
      JSON.stringify({
        subscriptionType: styp,
        courseId: props?.data?.obj?.courseId,
        courseName: props?.data?.obj?.courseTitle,
        packId: priceList[selectedPack] ? priceList[selectedPack]?.packId : "",
        promoCode: appliedPromoCode,
      })
    );
    // window.location.href = "/create-account-process";
    setRegister(true)
  }

  // Set session storage to courseId
  useEffect(() => {
    if (window) {
      let params = new URL(document.location).searchParams;
      let course_id = params.get("course");
      if (course_id) {
        sessionStorage.setItem("course", course_id);
      }
    }
  }, []);

  useEffect(() => {
    if (
      (props.data && !props.data.obj) ||
      (courseArr && courseArr.length > 2)
    ) {
      window.location.href = "/404";
      return false;
    }
    setApplyPromoCodeDone(false);
    if (
      props.data &&
      props.data.obj &&
      props.data.obj.priceList &&
      props.data.obj.priceList.length > 0
    ) {
      setPriceList(props?.prices?.obj?.priceList);
      setPayableAmount(props.data.obj.priceList[selectedPack].salePrice);
      setCode("");
      setAppliedPromoCode("");
    }
  }, [props.data]);

  function applyPromoCode() {
    if (code) {
      setApplyPromoCodeLoading(true);
      getApiPromoCode(code);
    } else {
      setSeverityAlert("error");
      setAlertMessage("Enter promotional code");
      return false;
    }
  }

  async function getApiPromoCode(code) {
    let axiosHeader = {
      headers: {
        "Content-Type": "multipart/mixed",
      },
    };
    let apiURL =
      process.env.NEXT_PUBLIC_API_URL +
      "/web-verifypromocode-multiple-pricing?webUrl=" +
      process.env.NEXT_PUBLIC_WEB_URL_FOR_COURSES +
      "&promoCode=" +
      code +
      "&courseId=" +
      props.data.obj.courseId;
    axios.get(apiURL, axiosHeader).then((response) => {
      setApplyPromoCodeLoading(false);
      if (
        response &&
        response.data &&
        response.data.responseTxt === "success"
      ) {
        setPriceList(response.data.priceList);
        if (response.data.priceList && response.data.priceList.length > 0) {
          setPayableAmount(response.data.priceList[selectedPack].salePrice);
        }
        setApplyPromoCodeDone(true);
        setAppliedPromoCode(code);
        setSeverityAlert("success");
        setAlertMessage("Promotional code has been applied successfully.");
        return false;
      } else if (
        response &&
        response.data &&
        response.data.responseTxt === "invalid"
      ) {
        setSeverityAlert("error");
        setAlertMessage("Promotional code is invalid.");
        return false;
      } else {
        setSeverityAlert("error");
        setAlertMessage("Something wrong with promotional code to apply.");
        return false;
      }
    });
  }

  function getTabIndex() {
    if (
      courseArr &&
      courseArr[1] &&
      courseArr[1].length > 0 &&
      props.data.obj.tabs &&
      props.data.obj.tabs.length > 0
    ) {
      for (let i = 0; i < props.data.obj.tabs.length; i++) {
        if (courseArr[1] === props.data.obj.tabs[i].tabUrl) {
          setTabObj(props.data.obj.tabs[i]);
          setTabIndex(i + 1);
          break;
        }
      }
    }
  }

  function selectTab(i) {
    if (i > -1 && props.data.obj.tabs && props.data.obj.tabs.length > 0) {
      courseArr[1] = props.data.obj.tabs[i].tabUrl;
      getTabIndex();
      window.history.replaceState(
        null,
        "",
        "/course/" + courseArr[0] + "/" + props.data.obj.tabs[i].tabUrl
      );
    } else {
      setTabObj({});
      setTabIndex(0);
      courseArr[1] = "";
      getTabIndex();
      window.history.replaceState(null, "", "/course/" + courseArr[0]);
    }
  }

  useEffect(() => {
    if (register) {
      document.body.scrollTop = 0; // For Safari
      document.documentElement.scrollTop = 0; // For Chrome, Firefox, IE and Opera
      document.querySelector("body").style.height = "100vh";
      document.querySelector("body").style.overflow = "hidden";
    } else {
      document.querySelector("body").style = "";
    }
  }, [register]);

  return (
    <>
      <Head>
        <title>
          {tabObj && tabObj.metaTitle && tabObj.metaTitle.length > 0
            ? tabObj.metaTitle
            : props.data && props.data.obj && props.data.obj.metaTitle
            ? props.data.obj.metaTitle
            : "Course Details"}
        </title>
        <meta
          name="description"
          content={
            tabObj &&
            tabObj.metaDescription &&
            tabObj.metaDescription.length > 0
              ? tabObj.metaDescription
              : props.data && props.data.obj && props.data.obj.metaDescription
              ? props.data.obj.metaDescription
              : null
          }
        />
        <meta
          name="keywords"
          content={
            tabObj && tabObj.metaKeywords && tabObj.metaKeywords.length > 0
              ? tabObj.metaKeywords
              : props.data && props.data.obj && props.data.obj.metaKeywords
              ? props.data.obj.metaKeywords
              : null
          }
        />
        <meta name="viewport" content="initial-scale=1.0, width=device-width" />
        <link
          rel="canonical"
          href={`https://easetolearn.com${
            props?.url?.split("?")?.length > 0
              ? props?.url?.split("?")[0]
              : props?.url
          }`}
        />

        <Schema />
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `{  
              "@context": "http://schema.org",
              "@type": "Product", 
              "aggregateRating": {    
                "@type": "AggregateRating",    
                "bestRating": "5",  
                "ratingCount": "${
                  props?.data?.obj?.ratingReviewsObj?.rating?.totalRating
                    ? props?.data?.obj?.ratingReviewsObj?.rating?.totalRating
                    : 50
                }",    
                "ratingValue": "${
                  props?.data?.obj?.ratingReviewsObj?.rating?.averageRating
                    ? props?.data?.obj?.ratingReviewsObj?.rating?.averageRating
                    : 4.4
                }"
              },
              "image": "https://media.easetolearn.com/CompanyLogo.svg",
              "name": "EaseToLearn", 
              "description": "${props?.data?.obj?.metaDescription}",
              "url": "https://easetolearn.com/course/${courseArr[0]}",
              "logo": "https://media.easetolearn.com/CompanyLogo.svg"
              }`,
          }}
        />
        <Favicon />
      </Head>
      <Layout current={props?.data?.obj}>
        <div className="topBGImgcorsDtl"></div>
        <Box className="mainBox" style={{ marginTop: -30 }}>
          {tabObj && tabObj.metaTitle && tabObj.metaTitle.length > 0 ? (
            <Box className="corseDtlTopBoxx">
              <Grid container>
                <Grid item md={12} sm={12} xs={12}>
                  <h1>{tabObj.metaTitle}</h1>
                </Grid>
                <Grid item md={12} sm={12} xs={12}>
                  <h4>{tabObj.metaDescription}</h4>
                </Grid>
              </Grid>
            </Box>
          ) : props.data && props.data.obj && props.data.obj.metaTitle ? (
            <Box className="corseDtlTopBoxx">
              <Grid container>
                <Grid item md={12} sm={12} xs={12}>
                  <h1>{props.data.obj.metaTitle}</h1>
                </Grid>
                <Grid item md={12} sm={12} xs={12}>
                  <h4>{props.data.obj.metaDescription}</h4>
                </Grid>
              </Grid>
            </Box>
          ) : null}
          <Box className="courseDtlTopBox">
            <Grid container>
              {/* <Grid item md={8} sm={6} xs={12}>
                <h1 style={{ whiteSpace: "nowrap", overflow: "hidden" }}>
                  {props.data && props.data.obj && props.data.obj.courseTitle
                    ? props.data.obj.courseTitle
                    : null}
                </h1>
                <h3 style={{ whiteSpace: "nowrap", overflow: "hidden" }}>
                  {props.data && props.data.obj && props.data.obj.courseSubTitle
                    ? props.data.obj.courseSubTitle
                    : null}
                </h3>
              </Grid> */}

              <Grid item md={12} sm={6} xs={12} className="bttonaa-box">
                <div
                  onClick={() => {
                    if (props?.accountDetails) {
                      selectThisCourse("Free");
                    } else {
                      Cookies.set(
                        "courseDetails",
                        JSON.stringify({
                          subscriptionType: "Free",
                          courseId: props?.data?.obj?.courseId,
                          courseName: props?.data?.obj?.courseTitle,
                          packId: "",
                          promoCode: "",
                        })
                      );
                      setRegister(true);
                    }
                  }}
                  className="bttonaa mybt-lightaa mttop30 gilroySemiBold"
                >
                  Sign Up for free Online Test
                </div>
                {props?.data?.obj?.priceType === 1 &&
                props.data.obj?.priceList?.length > 0 ? (
                  <a
                    href={`/packages?course=${props?.data?.obj?.courseUrl}`}
                    className="bttonaa mybt-lightaa mttop30 gilroySemiBold join_free_button"
                  >
                    View Plans
                  </a>
                ) : (
                  <></>
                )}
              </Grid>
            </Grid>
          </Box>

          <Box className={styles.course_tabs} style={{ marginBottom: 2 }}>
            {props.data &&
            props.data.obj &&
            props.data.obj.tabs &&
            props.data.obj.tabs[0] ? (
              <>
                <CourseDetailDesktop
                  tabs={props.data.obj.tabs}
                  selectTab={selectTab}
                  tabIndex={tabIndex}
                />
                <div className={styles?.course_tabsShadow}></div>
              </>
            ) : null}
          </Box>

          {(props?.tabObj || tabObj) &&
          (props?.courseArr?.length > 1 || tabIndex !== 0) &&
          courseArr[1]?.length > 0 ? (
            <Box className="courseTabBox">
              <Typography
                variant="h6"
                style={{
                  marginBottom: 20,
                  color: "#22436E",
                  fontWeight: "bold",
                }}
              >
                {props.data && props.data.obj && props.data.obj.courseTitle
                  ? props.data.obj.courseTitle
                  : null}{" "}
                {tabObj?.heading ? tabObj?.heading : props?.tabObj.heading}
              </Typography>
              <Box>
                <div className="courseDtlTabContent">
                  <div
                    className="course_story"
                    dangerouslySetInnerHTML={{
                      __html: tabObj?.details
                        ? tabObj?.details
                        : props?.tabObj?.details,
                    }}
                  />
                  <div style={{ marginTop: 10 }}>
                    #Note: The information provided above is just an indicative
                    information of what is provided, and available. We make no
                    such claim about the accuracy and reliability of this
                    information. For more accurate/current information, please
                    visit or contact the concerned
                    institute/college/authorities.
                  </div>
                </div>
              </Box>
            </Box>
          ) : (
            <Box>
              <Box className="featuresBox">
                <Grid container>
                  <Grid item md={12} sm={12} xs={12}>
                    <p className="headingTxt">Key Features</p>
                    <ul>
                      <Grid container spacing={2}>
                        <Grid item md={6} sm={12} xs={12}>
                          <h2
                            className="color-dark"
                            style={{ textAlign: "center", marginBottom: 15 }}
                          >
                            MY Study Room™
                          </h2>
                          {props.data &&
                          props.data.obj &&
                          props.data.obj.studyRoom
                            ? props.data.obj.studyRoom
                                .split("\n")
                                .map((myRow, index) => (
                                  <>
                                    {myRow.indexOf("==") > -1 ? (
                                      <li key={index}>
                                        <div className="icon">
                                          <StarIcon style={{ fontSize: 13 }} />
                                        </div>
                                        <div className="txtsection">
                                          <h4>{myRow.split("==")[0]}</h4>
                                          <p>
                                            {myRow
                                              .split("==")[1]
                                              .indexOf("##") > -1 ? (
                                              <ul className="featurepoints">
                                                {myRow
                                                  .split("==")[1]
                                                  .split("##")
                                                  .map((myPoint, indexLi) => (
                                                    <li key={"pt" + indexLi}>
                                                      - {myPoint}
                                                    </li>
                                                  ))}
                                              </ul>
                                            ) : (
                                              <>{myRow.split("==")[1]}</>
                                            )}
                                          </p>
                                        </div>
                                      </li>
                                    ) : (
                                      <Grid container spacing={2} key={index}>
                                        <Grid item xs={12}>
                                          <li>
                                            <div className="icon">
                                              <StarIcon
                                                style={{ fontSize: 13 }}
                                              />
                                            </div>{" "}
                                            {myRow}
                                          </li>
                                        </Grid>
                                      </Grid>
                                    )}
                                  </>
                                ))
                            : null}
                        </Grid>

                        {props.data.obj?.priceType === 1 ? (
                          <Grid item md={6} sm={12} xs={12}>
                            <h2
                              className="color-dark"
                              style={{ textAlign: "center", marginBottom: 15 }}
                            >
                              MY Exam Room™
                            </h2>
                            {props.data &&
                            props.data.obj &&
                            props.data.obj.examPrep
                              ? props.data.obj.examPrep
                                  .split("\n")
                                  .map((myRow, index) => (
                                    <>
                                      {myRow.indexOf("==") > -1 ? (
                                        <li key={index}>
                                          <div className="icon">
                                            <StarIcon
                                              style={{ fontSize: 13 }}
                                            />
                                          </div>
                                          <div className="txtsection">
                                            <h4>{myRow.split("==")[0]}</h4>
                                            <p>
                                              {myRow
                                                .split("==")[1]
                                                .indexOf("##") > -1 ? (
                                                <ul className="featurepoints">
                                                  {myRow
                                                    .split("==")[1]
                                                    .split("##")
                                                    .map((myPoint, indexLi) => (
                                                      <li key={"pt" + indexLi}>
                                                        - {myPoint}
                                                      </li>
                                                    ))}
                                                </ul>
                                              ) : (
                                                <>{myRow.split("==")[1]}</>
                                              )}
                                            </p>
                                          </div>
                                        </li>
                                      ) : (
                                        <Grid container spacing={2}>
                                          <Grid item xs={12}>
                                            <li>
                                              <div className="icon">
                                                <StarIcon
                                                  style={{ fontSize: 13 }}
                                                />
                                              </div>{" "}
                                              {myRow}
                                            </li>
                                          </Grid>
                                        </Grid>
                                      )}
                                    </>
                                  ))
                              : null}
                          </Grid>
                        ) : (
                          <></>
                        )}
                      </Grid>
                    </ul>
                  </Grid>
                </Grid>
              </Box>

              {props.data.obj?.priceType === 1 &&
              props.data.obj?.priceList?.length > 0 ? (
                <Box className="coursePriceBox" style={{ marginTop: 50 }}>
                  <Box>
                    <Grid container className="innerOneBox">
                      <Grid item xs={12}>
                        <h2
                          style={{
                            textAlign: "center",
                            color: "#FFF",
                            marginTop: 15,
                          }}
                        >
                          Plans
                        </h2>
                        <div
                          style={{
                            width: "100%",
                            display: "flex",
                            alignItems: "center",
                            justifyContent: "center",
                            padding: "20px",
                          }}
                        >
                          <div
                            style={{
                              width: "100%",
                              display: "flex",
                              alignItems: "center",
                              justifyContent: "space-evenly",
                              background: "rgba(255, 255, 255, 0.2)",
                              borderRadius: "10px",
                              border: "1px solid rgba(255, 255, 255, 0.4)",
                              padding: "20px",
                              color: "#fff",
                              flexDirection: "column",
                            }}
                          >
                            <div
                              style={{
                                width: "100%",
                                display: "flex",
                                alignItems: "center",
                                justifyContent: "flex-start",
                              }}
                            >
                              <div style={{ flex: 0.6 }}></div>
                              <span
                                style={{
                                  flex: 0.2,
                                  fontWeight: "900",
                                  fontFamily: "Gilroy-black",
                                }}
                              >
                                ACE
                              </span>
                              <span
                                style={{
                                  flex: 0.2,
                                  fontWeight: "900",
                                  fontFamily: "Gilroy-black",
                                }}
                              >
                                PRO
                              </span>
                            </div>
                            <div
                              style={{
                                width: "100%",
                                display: "flex",
                                alignItems: "center",
                                justifyContent: "flex-start",
                                marginTop: "20px",
                                borderBottom:
                                  "1px solid rgba(255, 255, 255, 0.4)",
                                paddingBottom: "20px",
                              }}
                            >
                              <div style={{ flex: 0.6 }}>
                                <h3>My Study Room</h3>
                                {/* <p>Study Material</p> */}
                              </div>
                              <div
                                style={{
                                  flex: 0.2,
                                  fontSize: "18px",
                                  paddingLeft: "21px",
                                }}
                              >
                                <span>&#10003;</span>
                              </div>
                              <div
                                style={{
                                  flex: 0.2,
                                  fontSize: "16px",
                                  paddingLeft: "10px",
                                }}
                              >
                                <span>&#10060;</span>
                              </div>
                            </div>
                            <div
                              style={{
                                width: "100%",
                                display: "flex",
                                alignItems: "center",
                                justifyContent: "flex-start",
                                marginTop: "20px",
                              }}
                            >
                              <div style={{ flex: 0.6 }}>
                                <h3>My Exam Room</h3>
                                {/* <p>Topic Tests and Mock Tests</p> */}
                              </div>
                              <div
                                style={{
                                  flex: 0.2,
                                  fontSize: "18px",
                                  paddingLeft: "21px",
                                }}
                              >
                                <span>&#10003;</span>
                              </div>
                              <div
                                style={{
                                  flex: 0.2,
                                  fontSize: "18px",
                                  paddingLeft: "10px",
                                }}
                              >
                                <span>&#10003;</span>
                              </div>
                            </div>
                          </div>
                        </div>
                      </Grid>
                    </Grid>
                    <Grid container className="innerOneBox">
                      {/* <Grid item md={9} sm={8} xs={12}> */}
                      <div className="innerLeftBox">
                        <div className="course_box_alignment">
                          {priceList && priceList.length > 0
                            ? priceList
                                ?.slice(0, priceList?.length / 2)
                                ?.map((row, i) => {
                                  return (
                                    <div className="course_box_alignment">
                                      <div
                                        key={"a" + i}
                                        style={
                                          selectedPack === i
                                            ? packSelected
                                            : packNonSelected
                                        }
                                      >
                                        <Grid
                                          container
                                          spacing={2}
                                          onClick={() => {
                                            handleSelectedPack(i);
                                          }}
                                          style={{
                                            cursor: "pointer",
                                            position: "relative",
                                          }}
                                        >
                                          <Grid item md={4} sm={12} xs={12}>
                                            <Grid container>
                                              <Grid item xs={1}>
                                                {selectedPack === i ? (
                                                  <CheckIcon
                                                    style={{ color: "#fc5902" }}
                                                  />
                                                ) : (
                                                  <input
                                                    type="radio"
                                                    name="radio-buttons"
                                                    value={i}
                                                    onChange={() => {
                                                      handleSelectedPack(i);
                                                    }}
                                                    style={{
                                                      width: 20,
                                                      height: 20,
                                                    }}
                                                  />
                                                )}
                                              </Grid>
                                              <Grid item xs={11}>
                                                <div
                                                  style={{
                                                    fontWeight: "bold",
                                                    marginLeft: 10,
                                                  }}
                                                >
                                                  <div
                                                    style={{
                                                      marginBottom: "5px",
                                                    }}
                                                  >
                                                    {row.title}
                                                  </div>
                                                  <span
                                                    style={{
                                                      position: "absolute",
                                                      top: "-20px",
                                                      left: 0,
                                                      marginBottom: "5px",
                                                      fontWeight: "900",
                                                    }}
                                                  >
                                                    {row?.packType}
                                                  </span>
                                                  <div
                                                    style={
                                                      selectedPack === i
                                                        ? {
                                                            fontWeight: "bold",
                                                            fontSize: 15,
                                                            color: "#fc5902",
                                                          }
                                                        : {
                                                            fontWeight: "bold",
                                                            fontSize: 12,
                                                            color: "#FFF",
                                                          }
                                                    }
                                                  >
                                                    {row.discount ? (
                                                      <span>
                                                        SAVE {row.discount}%
                                                      </span>
                                                    ) : null}
                                                  </div>
                                                </div>
                                              </Grid>
                                            </Grid>
                                          </Grid>
                                          <Grid item md={4} sm={12} xs={12}>
                                            <div
                                              style={{ textAlign: "center" }}
                                            >
                                              <div
                                                style={{ fontWeight: "bold" }}
                                              >
                                                Validity up to{" "}
                                                {row.validityDate}
                                              </div>
                                            </div>
                                          </Grid>
                                          <Grid item md={4} sm={12} xs={12}>
                                            <div style={{ textAlign: "right" }}>
                                              <div
                                                style={{ fontWeight: "bold" }}
                                              >
                                                <div
                                                  style={
                                                    selectedPack === i
                                                      ? {
                                                          fontSize: 24,
                                                          color: "#008000",
                                                        }
                                                      : {
                                                          fontSize: 24,
                                                          color: "#FFF",
                                                        }
                                                  }
                                                >
                                                  &#8377;{row.salePrice}
                                                </div>
                                                {row.discount ? (
                                                  <div
                                                    style={
                                                      selectedPack === i
                                                        ? {
                                                            // marginTop: 10,
                                                            fontWeight: "bold",
                                                            fontSize: 16,
                                                            color: "#fc5902",
                                                          }
                                                        : {
                                                            // marginTop: 10,
                                                            fontWeight: "bold",
                                                            fontSize: 16,
                                                            color: "#FFF",
                                                          }
                                                    }
                                                  >
                                                    <strike>
                                                      &#8377;{row.retailPrice}
                                                    </strike>
                                                  </div>
                                                ) : null}
                                              </div>
                                            </div>
                                          </Grid>
                                        </Grid>
                                        {row.description &&
                                        row.description.length > 5 ? (
                                          <div style={{ marginLeft: 30 }}>
                                            {row.description}
                                          </div>
                                        ) : null}
                                      </div>
                                    </div>
                                  );
                                })
                            : null}
                        </div>
                        <div className="course_box_alignment">
                          {priceList && priceList.length > 0
                            ? priceList
                                ?.slice(priceList?.length / 2)
                                ?.map((row, i) => {
                                  return (
                                    <div
                                      className="course_box_alignment"
                                      style={{ marginTop: 10 }}
                                    >
                                      <div
                                        key={"a" + i + priceList?.length / 2}
                                        style={
                                          selectedPack ===
                                          i + priceList?.length / 2
                                            ? packSelected
                                            : packNonSelected
                                        }
                                      >
                                        <Grid
                                          container
                                          spacing={2}
                                          onClick={() => {
                                            handleSelectedPack(
                                              i + priceList?.length / 2
                                            );
                                          }}
                                          style={{
                                            cursor: "pointer",
                                            position: "relative",
                                          }}
                                        >
                                          <Grid item md={4} sm={12} xs={12}>
                                            <Grid container>
                                              <Grid item xs={1}>
                                                {selectedPack ===
                                                i + priceList?.length / 2 ? (
                                                  <CheckIcon
                                                    style={{ color: "#fc5902" }}
                                                  />
                                                ) : (
                                                  <input
                                                    type="radio"
                                                    name="radio-buttons"
                                                    value={
                                                      i + priceList?.length / 2
                                                    }
                                                    onChange={() => {
                                                      handleSelectedPack(
                                                        i +
                                                          priceList?.length / 2
                                                      );
                                                    }}
                                                    style={{
                                                      width: 20,
                                                      height: 20,
                                                    }}
                                                  />
                                                )}
                                              </Grid>
                                              <Grid item xs={11}>
                                                <div
                                                  style={{
                                                    fontWeight: "bold",
                                                    marginLeft: 10,
                                                  }}
                                                >
                                                  <div
                                                    style={{
                                                      marginBottom: "5px",
                                                    }}
                                                  >
                                                    {row.title}
                                                  </div>
                                                  <span
                                                    style={{
                                                      position: "absolute",
                                                      top: "-20px",
                                                      left: 0,
                                                      marginBottom: "5px",
                                                      fontWeight: "900",
                                                    }}
                                                  >
                                                    {row?.packType}
                                                  </span>
                                                  <div
                                                    style={
                                                      selectedPack ===
                                                      i + priceList?.length / 2
                                                        ? {
                                                            fontWeight: "bold",
                                                            fontSize: 15,
                                                            color: "#fc5902",
                                                          }
                                                        : {
                                                            fontWeight: "bold",
                                                            fontSize: 12,
                                                            color: "#FFF",
                                                          }
                                                    }
                                                  >
                                                    {row.discount ? (
                                                      <span>
                                                        SAVE {row.discount}%
                                                      </span>
                                                    ) : null}
                                                  </div>
                                                </div>
                                              </Grid>
                                            </Grid>
                                          </Grid>
                                          <Grid item md={4} sm={12} xs={12}>
                                            <div
                                              style={{ textAlign: "center" }}
                                            >
                                              <div
                                                style={{ fontWeight: "bold" }}
                                              >
                                                Validity up to{" "}
                                                {row.validityDate}
                                              </div>
                                            </div>
                                          </Grid>
                                          <Grid item md={4} sm={12} xs={12}>
                                            <div style={{ textAlign: "right" }}>
                                              <div
                                                style={{ fontWeight: "bold" }}
                                              >
                                                <div
                                                  style={
                                                    selectedPack ===
                                                    i + priceList?.length / 2
                                                      ? {
                                                          fontSize: 24,
                                                          color: "#008000",
                                                        }
                                                      : {
                                                          fontSize: 24,
                                                          color: "#FFF",
                                                        }
                                                  }
                                                >
                                                  &#8377;{row.salePrice}
                                                </div>
                                                {row.discount ? (
                                                  <div
                                                    style={
                                                      selectedPack ===
                                                      i + priceList?.length / 2
                                                        ? {
                                                            // marginTop: 10,
                                                            fontWeight: "bold",
                                                            fontSize: 16,
                                                            color: "#fc5902",
                                                          }
                                                        : {
                                                            // marginTop: 10,
                                                            fontWeight: "bold",
                                                            fontSize: 16,
                                                            color: "#FFF",
                                                          }
                                                    }
                                                  >
                                                    <strike>
                                                      &#8377;{row.retailPrice}
                                                    </strike>
                                                  </div>
                                                ) : null}
                                              </div>
                                            </div>
                                          </Grid>
                                        </Grid>
                                        {row.description &&
                                        row.description.length > 5 ? (
                                          <div style={{ marginLeft: 30 }}>
                                            {row.description}
                                          </div>
                                        ) : null}
                                      </div>
                                    </div>
                                  );
                                })
                            : null}
                        </div>
                      </div>
                      {/* </Grid> */}
                      {/* <Grid item md={3} sm={4} xs={12}>
                        <div className="innerRightBox">
                          <p className="benefitsHeading">Benefits:</p>
                          <p>
                            <ul>
                              <li>24 x 7 Online Access</li>
                              <li>Unlimited Test</li>
                              <li>Mock Test</li>
                              <li>Reports & Analytics</li>
                              <li>All India Rank</li>
                              <li>Time Management</li>
                              <li>Chapter Test</li>
                              <li>Online Teacher Support</li>
                              <li>Subject Test</li>
                            </ul>
                          </p>
                        </div>
                      </Grid> */}
                    </Grid>
                  </Box>
                  <Box className="belowAATwoBox">
                    <Grid container>
                      <Grid item md={6} sm={6} xs={12}>
                        <div style={{ marginTop: 20 }}>
                          {severityAlert === "error" ? (
                            <div
                              style={{ color: "#FF0000", fontWeight: "bold" }}
                            >
                              {alertMessage}
                            </div>
                          ) : (
                            <div
                              style={{ color: "#00FF00", fontWeight: "bold" }}
                            >
                              {alertMessage}
                            </div>
                          )}
                          {!applyPromoCodeDone ? (
                            <>
                              <Grid container>
                                <Grid item md={5} sm={5} xs={12}>
                                  <div>Apply promotional code if any</div>
                                  <CssTextField
                                    onChange={(event) =>
                                      setCode(event.target.value)
                                    }
                                    value={code}
                                    size="small"
                                    variant="outlined"
                                    fullWidth
                                    inputProps={{ maxLength: 50 }}
                                    placeholder="Enter promo code"
                                  />
                                </Grid>
                                <Grid item md={7} sm={7} xs={12}>
                                  <div style={{ marginTop: 30, marginLeft: 5 }}>
                                    {applyPromoCodeLoading ? (
                                      <a className="mybttonpaynow">
                                        <CircularProgress
                                          size={13}
                                          color={"inherit"}
                                        />{" "}
                                        Wait...
                                      </a>
                                    ) : (
                                      <a
                                        href="javascript:;"
                                        onClick={() => {
                                          applyPromoCode();
                                        }}
                                        className="mybttonpaynow"
                                      >
                                        Apply
                                      </a>
                                    )}
                                  </div>
                                </Grid>
                              </Grid>
                              <div style={{ marginTop: 15 }}>
                                {props.data &&
                                props.data.obj &&
                                props.data.obj.promoList &&
                                props.data.obj.promoList.length > 0
                                  ? props.data.obj.promoList.map(
                                      (myPC, pcKey) => (
                                        <span
                                          key={"pca" + pcKey}
                                          style={{ marginLeft: 5 }}
                                        >
                                          <LocalOfferIcon
                                            style={{
                                              color: "#FFF",
                                              fontSize: 10,
                                            }}
                                          />{" "}
                                          {myPC.description}
                                        </span>
                                      )
                                    )
                                  : null}
                              </div>
                            </>
                          ) : null}
                        </div>
                      </Grid>
                      <Grid
                        item
                        md={6}
                        sm={6}
                        xs={12}
                        style={{ textAlign: "right" }}
                      >
                        <div style={{ marginTop: 30 }}>
                          <a
                            href="javascript:;"
                            onClick={() => {
                              selectThisCourse("Paid");
                            }}
                            className="mybtplan"
                          >
                            Just Pay &#8377;{payableAmount}
                          </a>
                        </div>
                      </Grid>
                    </Grid>
                  </Box>
                </Box>
              ) : (
                <></>
              )}

              <Box style={{ marginTop: 40 }}>
                <section className="mycontainer ">
                  <div className="barbox-head color-dark">
                    <h2 className="fixhead">Related Courses</h2>
                    <div className="bar bg-dark"></div>
                  </div>
                </section>

                <section className="mycontainer relative ">
                  {props.data &&
                  props.data.obj &&
                  props.data.obj.relatedCourses ? (
                    <RelatedCourses courses={props.data.obj.relatedCourses} />
                  ) : null}

                  <div
                    style={{
                      display: "flex",
                      justifyContent: "center",
                      alignItems: "center",
                      marginTop: 40,
                    }}
                  >
                    <div style={{ width: 200, textAlign: "center" }}>
                      <Link href="/courses">
                        <a className="btn sellerbt ">view more</a>
                      </Link>
                    </div>
                  </div>
                </section>
              </Box>

              {/************ RATING AND REVIEWS BOX **********************************/}
              {props.data &&
              props.data.obj &&
              props.data.obj.ratingReviewsObj &&
              props.data.obj.ratingReviewsObj.rating &&
              props.data.obj.ratingReviewsObj.rating.totalRating > 0 ? (
                <Box className="ratingBox">
                  <Grid container>
                    <Grid item md={12} sm={12} xs={12}>
                      <p className="headingTxt">Rating &amp; Reviews</p>
                      <Grid container spacing={2}>
                        <Grid item md={4} sm={12} xs={12}>
                          <div className="totalRatingBox">
                            <div className="avgRating">
                              {
                                props.data.obj.ratingReviewsObj.rating
                                  .averageRating
                              }
                            </div>
                            {props.data &&
                            props.data.obj &&
                            props.data.obj.ratingReviewsObj &&
                            props.data.obj.ratingReviewsObj.rating
                              .averageRating ? (
                              <Rating
                                defaultValue={
                                  props.data.obj.ratingReviewsObj.rating
                                    .averageRating
                                }
                                precision={0.5}
                                readOnly={true}
                              />
                            ) : null}
                            <div className="totalRating">
                              {
                                props.data.obj.ratingReviewsObj.rating
                                  .totalRating
                              }{" "}
                              Rating
                            </div>
                          </div>
                        </Grid>
                        <Grid item md={8} sm={12} xs={12}>
                          {props.data.obj.ratingReviewsObj.rating.starFive &&
                          props.data.obj.ratingReviewsObj.rating.starFive >
                            0 ? (
                            <>
                              <Grid
                                container
                                spacing={2}
                                style={{ marginTop: 5 }}
                              >
                                <Grid item xs={6} className="barlabelleft">
                                  5 Star
                                </Grid>
                                <Grid item xs={6} className="barlabelright">
                                  {
                                    props.data.obj.ratingReviewsObj.rating
                                      .starFive
                                  }
                                  %
                                </Grid>
                              </Grid>
                              <BorderLinearProgress
                                variant="determinate"
                                value={
                                  props.data.obj.ratingReviewsObj.rating
                                    .starFive
                                }
                              />
                            </>
                          ) : null}

                          {props.data.obj.ratingReviewsObj.rating.starFour &&
                          props.data.obj.ratingReviewsObj.rating.starFour >
                            0 ? (
                            <>
                              <Grid
                                container
                                spacing={2}
                                style={{ marginTop: 8 }}
                              >
                                <Grid item xs={6} className="barlabelleft">
                                  4 Star
                                </Grid>
                                <Grid item xs={6} className="barlabelright">
                                  {
                                    props.data.obj.ratingReviewsObj.rating
                                      .starFour
                                  }
                                  %
                                </Grid>
                              </Grid>
                              <BorderLinearProgress
                                variant="determinate"
                                value={
                                  props.data.obj.ratingReviewsObj.rating
                                    .starFour
                                }
                              />
                            </>
                          ) : null}

                          {props.data.obj.ratingReviewsObj.rating.starThree &&
                          props.data.obj.ratingReviewsObj.rating.starThree >
                            0 ? (
                            <>
                              <Grid
                                container
                                spacing={2}
                                style={{ marginTop: 8 }}
                              >
                                <Grid item xs={6} className="barlabelleft">
                                  3 Star
                                </Grid>
                                <Grid item xs={6} className="barlabelright">
                                  {
                                    props.data.obj.ratingReviewsObj.rating
                                      .starThree
                                  }
                                  %
                                </Grid>
                              </Grid>
                              <BorderLinearProgress
                                variant="determinate"
                                value={
                                  props.data.obj.ratingReviewsObj.rating
                                    .starThree
                                }
                              />
                            </>
                          ) : null}

                          {props.data.obj.ratingReviewsObj.rating.starTwo &&
                          props.data.obj.ratingReviewsObj.rating.starTwo > 0 ? (
                            <>
                              <Grid
                                container
                                spacing={2}
                                style={{ marginTop: 8 }}
                              >
                                <Grid item xs={6} className="barlabelleft">
                                  2 Star
                                </Grid>
                                <Grid item xs={6} className="barlabelright">
                                  {
                                    props.data.obj.ratingReviewsObj.rating
                                      .starTwo
                                  }
                                  %
                                </Grid>
                              </Grid>
                              <BorderLinearProgress
                                variant="determinate"
                                value={
                                  props.data.obj.ratingReviewsObj.rating.starTwo
                                }
                              />
                            </>
                          ) : null}

                          {props.data.obj.ratingReviewsObj.rating.starOne &&
                          props.data.obj.ratingReviewsObj.rating.starOne > 0 ? (
                            <>
                              <Grid
                                container
                                spacing={2}
                                style={{ marginTop: 8 }}
                              >
                                <Grid item xs={6} className="barlabelleft">
                                  1 Star
                                </Grid>
                                <Grid item xs={6} className="barlabelright">
                                  {
                                    props.data.obj.ratingReviewsObj.rating
                                      .starOne
                                  }
                                  %
                                </Grid>
                              </Grid>
                              <BorderLinearProgress
                                variant="determinate"
                                value={
                                  props.data.obj.ratingReviewsObj.rating.starOne
                                }
                              />
                            </>
                          ) : null}
                        </Grid>
                      </Grid>

                      {reviews && reviews.length > 0
                        ? reviews.map((row, i) => (
                            <Box key={"bx" + i} className="reviewbox">
                              <Grid container spacing={2}>
                                <Grid item md={1} sm={2} xs={12}>
                                  <div
                                    style={{
                                      justifyContent: "center",
                                      display: "flex",
                                    }}
                                  >
                                    <Avatar
                                      alt={row.studentName}
                                      src={row.profilePic}
                                      sx={{ width: 56, height: 56 }}
                                    />
                                  </div>
                                </Grid>
                                <Grid item md={11} sm={10} xs={12}>
                                  <div>
                                    <span className="title">
                                      {row.studentName}
                                    </span>{" "}
                                    {row.createdDateTime}
                                  </div>
                                  <div>
                                    <Rating
                                      defaultValue={row.rating}
                                      readOnly={true}
                                      precision={0.5}
                                    />
                                  </div>
                                  <div>{row.remarks}</div>
                                </Grid>
                              </Grid>
                            </Box>
                          ))
                        : null}

                      {props.data &&
                      props.data.obj &&
                      props.data.obj.ratingReviewsObj &&
                      totalRecords <
                        props.data.obj.ratingReviewsObj.rating.totalRating ? (
                        <Grid item xs={12} style={{ textAlign: "right" }}>
                          <div style={{ marginTop: 30 }}>
                            <a
                              href="javascript:;"
                              onClick={() => {
                                moreReviews();
                              }}
                              className="mybttonpaynow"
                            >
                              More Reviews
                            </a>
                          </div>
                        </Grid>
                      ) : null}
                    </Grid>
                  </Grid>
                </Box>
              ) : null}
              {/************ RATING AND REVIEWS BOX **********************************/}
            </Box>
          )}
          {/* Tab box	close		 */}
        </Box>
        <Box style={{ marginTop: 40 }}></Box>
        {register ? (
          <RegisterModal
            status={status}
            setStatus={setStatus}
            registerPopup={register}
            setRegisterPopup={setRegister}
          />
        ) : (
          <></>
        )}
      </Layout>
    </>
  );
}

export async function getServerSideProps(context) {
  try {
    const coursearr = context.query.params || [];
    const accountDetails = context.req.cookies["accountDetails"];
    const res = await fetch(
      process.env.NEXT_PUBLIC_API_URL +
        "/website-course-details-mpricing?courseUrl=" +
        coursearr[0]
    );
    const data = await res.json();
    const price = await fetch(
      process.env.NEXT_PUBLIC_API_URL +
        "/website-course-pricing?courseId=" +
        data?.obj?.courseId
    );
    const prices = await price.json();

    let response =
      coursearr?.length > 1
        ? await fetch(
            process.env.NEXT_PUBLIC_API_URL +
              `/website-course-details-mpricing?courseUrl=${coursearr[0]}&tabUrl=${coursearr[1]}`
          )
        : "";
    let tabData;
    if (response) {
      tabData = await response.json();
    }
    return {
      props: {
        prices,
        data,
        tabObj: tabData ? tabData?.obj?.tabObj : {},
        courseArr: coursearr,
        url: context?.req?.url,
        accountDetails: accountDetails || null,
      },
    };
  } catch (err) {
    console.log("API Calling error: ", err);
  }
  return { props: {} };
}
