import React, { useState, useEffect } from "react";
import Head from "next/head";
import { useRouter } from "next/router";
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid } from "@material-ui/core";
import SearchInput from "../../components/SearchInput";
import CoursesMobile from "../../components/CoursesMobile";
import CoursesDesktop from "../../components/CoursesDesktop";
import Cookies from "js-cookie";
import Favicon from "../../client/Favicon";
import Meta from "../../client/Meta";
import { coursesMeta } from "../../utils/Constants/metaConstants";
import Schema from "../../client/Schema";
import { getKeywordsCourses } from "../../utils";
import Layout from "../../client/Layout";

export default function Home(props) {
  // Router
  const router = useRouter();
  // Cookies
  const courseCategoryIndex = Cookies.get("courseCategoryTabIndex");
  const accountDetails = Cookies.get("accountDetails");
  const newUser = Cookies.get("new_user");
  let joinFree = Cookies.get("header_join_for_free");
  const classes = useStyles();

  const selectCourseCategory = (i) => {
    Cookies.set("courseCategoryTabIndex", i);
  };

  // Get the initial list for schema
  const getList = () => {
    const id = props.data?.list?.findIndex((object) => {
      const url = router?.query?.slug[0]?.toLowerCase()?.split("-");
      const length = url?.length > 1;
      return (
        object?.categoryName?.toLowerCase() ===
        (length ? url?.join(" ") : url[0])
      );
    });
    const list = props?.data?.list[id];
    return list?.coursesList;
  };

  const url = router?.query?.slug[0];
  const title =
    url?.split("-")?.length > 1
      ? url?.split("-")?.join(" ")[0]?.toUpperCase() +
        url?.split("-")?.join(" ")?.substr(1)
      : url[0].toUpperCase() + url?.substr(1);

  // All States
  const [pageTitle, setPageTitle] = useState(title);
  const [pageSlug, setPageSlug] = useState(router?.query?.slug[0]);
  const [pageCourseList, setPageCourseList] = useState(getList());
  const [pageKeywords, setPageKeywords] = useState(
    getKeywordsCourses(getList())
  );

  let schema = {
    breadcrumbs: [
      {
        id: "https://www.easetolearn.com/",
        name: "Home",
      },
      {
        id: `https://www.easetolearn.com/courses/${router?.query?.slug[0]}`,
        name: `${title}`,
      },
    ],
  };

  return (
    <>
      <Head>
        <title>
          {pageTitle} Courses: Free Online Courses, Course Series, Test Series &
          Practice Mock Test | MY Exam Room
        </title>
        <Meta
          meta={{
            ...coursesMeta,
            keywords: "",
          }}
          url={`courses/${pageSlug}`}
        />
        <meta name="keywords" content={pageKeywords} />
        <Favicon />
        <Schema schema={schema} />
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{
            __html: `{
                    "@context": "https://schema.org",
                    "@type": "ItemList",
                    "name": "${pageTitle} Courses",
                    "url": "https://easetolearn.com/courses/${pageSlug}",
                    "description": "All ${pageTitle} Courses Offerred By EaseToLearn.com",
                    "itemListElement": [
                      ${pageCourseList?.map((ele, key) => {
                        return `{
                                    "@type": "Course",
                                    "name": "${ele?.courseTitle}",
                                    "courseCode": "${ele?.courseId}",
                                    "provider": {
                                      "type": "Organization",
                                      "name": "EasetoLearn",
                                      "url": "https://easetolearn.com"
                                    },
                                    "url": "https://easetolearn.com/course/${
                                      ele?.courseUrl
                                    }",
                                    "description": "${ele?.courseSubTitle}",
                                    "position": "${key + 1}",
                                    "countryOfOrigin": "India",
                                    "hasCourseInstance": {
                                      "@type": "CourseInstance",
                                      "courseMode": "online",
                                      "courseWorkload": "Students must give atleast 3 mock tests per day.",
                                      "offers": {
                                        "@type": "Offer",
                                        "price": "${
                                          ele?.salePrice ? ele?.salePrice : 0
                                        }",
                                        "priceCurrency": "INR"
                                      },
                                      "endDate": "${ele?.validityDate}"
                                  }
                                }`;
                      })}
                    ]
                  }`,
          }}
        />
      </Head>
      <Layout>
        <Box className="mainBox" style={{ marginTop: -67 }}>
          <Box>
            <Grid
              container
              className="topBGImg adjustment_image"
              style={{ backgroundImage: "url(/our-courses.webp)" }}
              spacing={3}
            ></Grid>
          </Box>
          <Box alignItems="center" justifyContent="center">
            <Grid container style={{ justifyContent: "center" }}>
              <SearchInput data={props.data.list} />
            </Grid>

            {accountDetails ? (
              <Grid container>
                <Grid item md={12} sm={12} xs={12}>
                  <h2 style={{ color: "#22436e", textAlign: "center" }}>
                    Select your course to join for free
                  </h2>
                </Grid>
              </Grid>
            ) : null}
          </Box>

          <Box className={classes.sectionDesktop}>
            <CoursesDesktop
              data={props.data.list}
              courseCategoryIndex={courseCategoryIndex}
              selectCourseCategory={selectCourseCategory}
              slug={pageSlug}
              setPageSlug={setPageSlug}
              setPageTitle={setPageTitle}
              setPageCourseList={setPageCourseList}
              keywords={setPageKeywords}
              accountDetails={props?.accountDetails}
              newUser={props?.newUser}
              token={props?.token}
              joinFree={props?.joinFree || joinFree}
            />
          </Box>
          <Box className={classes.sectionMobile}>
            <CoursesMobile
              joinFree={props?.joinFree || joinFree}
              data={props.data.list}
              courseCategoryIndex={courseCategoryIndex}
              selectCourseCategory={selectCourseCategory}
              slug={pageSlug}
              token={props?.token}
              setPageSlug={setPageSlug}
              setPageTitle={setPageTitle}
              setPageCourseList={setPageCourseList}
              newUser={props?.newUser}
              keywords={setPageKeywords}
              accountDetails={props?.accountDetails}
            />
          </Box>
        </Box>
      </Layout>
    </>
  );
}

// Styles
const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

let joinFree;
let accountDetails;
let newUser;
let token;

export async function getServerSideProps(context) {
  if (!context?.resolvedUrl?.includes("/manifest")) {
    newUser = context.req.cookies["new_user"];
    token = context.req.cookies["token"];
    joinFree = context.req.cookies["header_join_for_free"];
    accountDetails = context.req.cookies["accountDetails"];
  }

  const res = await fetch(
    process.env.NEXT_PUBLIC_API_URL +
      "/website-categoryandcourses?webUrl=" +
      process.env.NEXT_PUBLIC_WEB_URL_FOR_COURSES
  );
  const data = await res.json();
  return {
    props: {
      data,
      joinFree: joinFree ? joinFree : null,
      accountDetails: accountDetails ? accountDetails : null,
      newUser: newUser ? newUser : false,
      token: token ? JSON.parse(token) : "",
    },
  };
}
