import React from "react";
import Head from "next/head";
import axios from "axios";
import CircularProgress from "@mui/material/CircularProgress";
import { Box, Grid } from "@material-ui/core";
import Header from "../components/Header";
import Footer from "../components/Footer";
import Cookies from "js-cookie";

export default function Home(props) {
  const accountDetails = Cookies.get("accountDetails");
  const courseDetails = Cookies.get("courseDetails");

  const [apiErrorMsg, setApiErrorMsg] = React.useState("");

  React.useEffect(() => {
    if (!accountDetails) {
      window.location.href = "/create-account";
    } else if (!courseDetails) {
      window.location.href = "/courses";
    } else if (accountDetails && courseDetails) {
      submit(accountDetails, courseDetails);
    }
  }, [accountDetails, courseDetails]);

  function submit(accountDetails, courseDetails) {
    if (accountDetails && courseDetails) {
      const objAccount = JSON.parse(accountDetails);
      const objCourse = JSON.parse(courseDetails);

      if (objCourse.subscriptionType === "Paid") {
        getPaidCourse(objAccount, objCourse);
        return false;
      }

      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("token", objAccount.token);
      data.append("courseId", objCourse.courseId);

      axios
        .post(process.env.NEXT_PUBLIC_API_URL + "/mobile-addcousetomyaccount", data, axiosHeader)
        .then((response) => {
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "OK") {
            window.location.href =
			process.env.NEXT_PUBLIC_LOGIN_URL + "/logindirect?loginKey=" + response.data.token;
            return false;
          } else {
            setApiErrorMsg("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setApiErrorMsg("" + error);
          return false;
        });
    }
  }

  function getPaidCourse(objAccount, objCourse) {
    if (objAccount && objCourse) {
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
          studentId: objAccount.studentId,
          token: objAccount.token,
        },
      };

      const data = new FormData();
      data.append("token", objAccount.token);
      data.append("courseId", objCourse.courseId);

      let apiQuery = "&webUrl=" + process.env.NEXT_PUBLIC_WEB_URL_FOR_COURSES;
      //let apiQuery='&webUrl='+window.location.host;
      if (objCourse && objCourse.promoCode && objCourse.promoCode.length > 0) {
        apiQuery += "&promoCode=" + objCourse.promoCode;
      }

      axios
        .get(
			process.env.NEXT_PUBLIC_API_URL +
            "/paymenttokengenerate-multiple-pricing?studentName=" +
            objAccount.studentName +
            "&email=" +
            objAccount.email +
            "&phone=" +
            objAccount.mobile +
            "&courseId=" +
            objCourse.courseId +
            "&courseName=" +
            objCourse.courseName +
            "&packId=" +
            objCourse.packId +
            apiQuery,
          axiosHeader
        )
        .then((response) => {
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "success") {
            if (response.data.amount > 0) {
              // window.location.href='http://localhost/rough-code/payment.php?key='+response.data.key+'&txnid='+response.data.token+'&amount='+response.data.amount+'&firstname='+objAccount.studentName+'&email='+objAccount.emailId+'&phone='+objAccount.phoneNo+'&productinfo='+response.data.productinfo+'&hash='+response.data.hashCode;
              // return false;
              document.pgform.key.value = response.data.key;
              document.pgform.txnid.value = response.data.token;
              document.pgform.amount.value = response.data.amount;
              document.pgform.firstname.value = objAccount.studentName;
              document.pgform.email.value = objAccount.email;
              document.pgform.phone.value = objAccount.mobile;
              document.pgform.productinfo.value = response.data.productinfo;
              document.pgform.surl.value = process.env.NEXT_PUBLIC_PAYMENT_GATEWAY_SUCCESS_URL;
              document.pgform.furl.value =
                "https://" + process.env.NEXT_PUBLIC_WEB_URL + "/pgcancelled";
              document.pgform.hash.value = response.data.hashCode;
              document.pgform.submit();
            } else {
              window.location.href =
			  process.env.NEXT_PUBLIC_LOGIN_URL + "/logindirect?loginKey=" + response.data.token;
              return false;
            }
          } else {
            setApiErrorMsg(
              "Seems like you have already signed up with us. You can subscribe to any course from your account. Redirecting you to your account in 10 seconds. Have a good day!"
            );
            const mytimeoutVar = setTimeout(redirectingToAccount, 10000);

            function redirectingToAccount() {
              window
                .open("https://student.easetolearn.com/selectcourse", "_blank")
                .focus();
              clearTimeout(mytimeoutVar);
            }
            return false;
          }
        })
        .catch((error) => {
          setApiErrorMsg("" + error);
          return false;
        });
    }
  }

  return (
    <>
      <Head>
        <title>Creating your account</title>
        <meta name="description" content="Creating your account" />
        <meta name="keywords" content="Creating your account" />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Box mt={1}>
                <Grid container spacing={2}>
                  <Grid item md={12} xs={12} style={{ textAlign: "center" }}>
                    {apiErrorMsg ? (
                      <>{apiErrorMsg}</>
                    ) : (
                      <>
                        <CircularProgress />
                        <br />
                        <span style={{ fontSize: 30, color: "#c51162" }}>
                          Wait...
                        </span>
                        <br />
                        {/* <span style={{fontSize:14,color:'#0000FF',fontWeight:'bold'}} >It is creating your account and setting up your courses</span> */}
                        <br />
                        <span style={{ fontWeight: "bold" }}>
                          Please do not close this window.
                        </span>
                      </>
                    )}
                  </Grid>
                </Grid>
              </Box>
            </Grid>
          </Box>

          <form
            name="pgform"
            action="https://secure.payu.in/_payment"
            method="post"
          >
            <input type="hidden" name="key" value="" />
            <input type="hidden" name="txnid" value="" />
            <input type="hidden" name="amount" value="" />
            <input type="hidden" name="productinfo" value="" />
            <input type="hidden" name="firstname" value="" />
            <input type="hidden" name="email" value="" />
            <input type="hidden" name="phone" value="" />
            <input type="hidden" name="surl" value="" />
            <input type="hidden" name="furl" value="" />
            <input type="hidden" name="hash" value="" />
          </form>
        </Box>

        <Footer />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
