import React from "react";
import Head from "next/head";
//import Image from 'next/image';
import axios from "axios";
import CircularProgress from "@mui/material/CircularProgress";
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import Header from "../components/Header";
import Footer from "../components/Footer";
import FormHelperText from "@mui/material/FormHelperText";
import Cookies from "js-cookie";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  const classes = useStyles();
  const [waitBtn, setWaitBtn] = React.useState(false);

  const [utype, setUtype] = React.useState("Learner");
  const [firstName, setFirstName] = React.useState("");
  const [lastName, setLastName] = React.useState("");
  const [mobileNumber, setMobileNumber] = React.useState("");
  const [email, setEmail] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");
  const [retypeNewPassword, setRetypeNewPassword] = React.useState("");
  const [courseId, setCourseId] = React.useState("");

  const [newPasswordMsg, setNewPasswordMsg] = React.useState("");
  const [retypeNewPasswordMsg, setRetypeNewPasswordMsg] = React.useState("");

  React.useEffect(() => {
    if (!newaccount) {
      window.location.href = "/create-account";
    } else if (newaccount) {
      const obj = JSON.parse(newaccount);
      setFirstName(obj.firstName);
      setLastName(obj.lastName);
      setMobileNumber(obj.mobile);
      setEmail(obj.email);
      setUtype(obj.utype);
    }
  }, [newaccount]);

  function submit() {
    if (!newPassword) {
      setNewPasswordMsg("Enter your password");
      return false;
    } else if (
      newPassword &&
      !newPassword
        .trim()
        .match(/^(?=.*[0-9])(?=.*[!@#$%^&*])[a-zA-Z0-9!@#$%^&*]{8,20}$/)
    ) {
      setNewPasswordMsg(
        "Must contain at least one number and one uppercase and lowercase letter and one special character, and at least 8 or more characters"
      );
      return false;
    } else {
      setNewPasswordMsg("");
    }
    if (!retypeNewPassword) {
      setRetypeNewPasswordMsg("Re-type your password");
      return false;
    } else if (newPassword !== retypeNewPassword) {
      setRetypeNewPasswordMsg("Re-typed password does not match with password");
      return false;
    } else {
      setRetypeNewPasswordMsg("");
    }

    if (newPassword && newPassword.length > 0) {
      setWaitBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

			let courseId = sessionStorage.getItem("course");
      console.log(courseId);

      if (!courseId) {
        window.location.href = "courses";
      } else {
        const data = new FormData();

        let apiURL = process.env.NEXT_PUBLIC_API_URL + "/newstudentregistration";
        let apiResponseTxt = "OK";
        if (utype && utype === "Teacher") {
          apiURL = process.env.NEXT_PUBLIC_API_URL + "/teacher-web-registration";
          apiResponseTxt = "success";
          data.append("teacherName", firstName + " " + lastName);
          data.append("mobile", mobileNumber);
          data.append("email", email);
          data.append("newPassword", newPassword);
        } else if (utype && utype === "Parent") {
          apiResponseTxt = "success";
          apiURL = process.env.NEXT_PUBLIC_API_URL + "/parent-web-registration";
          data.append("fullName", firstName + " " + lastName);
          data.append("mobile", mobileNumber);
          data.append("email", email);
          data.append("newPassword", newPassword);
        } else {
          data.append("studentName", firstName + " " + lastName);
          data.append("mobile", mobileNumber);
          data.append("email", email);
          data.append("newPassword", newPassword);
          data.append("courseId", courseId); //FREE Course 77
        }

        axios
          .post(apiURL, data, axiosHeader)
          .then((response) => {
            const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
            function myWaitBtnStop() {
              setWaitBtn(false);
              clearTimeout(myTimeoutWaitBtn);
            }
            ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
            if (response.data.responseTxt === apiResponseTxt) {
              if (utype && utype === "Teacher") {
                window.location.href =
                  "/teacher/login?token=" + response.data.token;
              } else if (utype && utype === "Parent") {
                window.location.href =
                  "/parent/login?token=" + response.data.obj.token;
              } else {
                Cookies.set(
                  "accountDetails",
                  JSON.stringify({
                    studentId: response.data.studentId,
                    studentName: firstName + " " + lastName,
                    mobile: mobileNumber,
                    email: email,
                    token: response.data.token,
                  })
                );
                Cookies.remove("newaccount");
                window.location.href = "/create-account-process";
              }
              return false;
            } else {
              setRetypeNewPasswordMsg("Error somewhere, Try after sometime.");
              return false;
            }
          })
          .catch((error) => {
            setRetypeNewPasswordMsg("" + error);
            return false;
          });
      }
    }
  }

  function onEnter(event) {
    if (event.key === "Enter") {
      submit();
    }
  }

  return (
    <>
      <Head>
        <title>Online Tests for Recruitment &amp; Entrance Exams</title>
        <meta
          name="description"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img
                  loading="lazy"
                  alt="ease to learn hero banner"
                  src="/two.webp"
                />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>Create your password</h1>
                <Grid className="frmbx">
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      New Password
                      <TextField
                        type="password"
                        onChange={(event) => setNewPassword(event.target.value)}
                        value={newPassword}
                        onKeyPress={(event) => {
                          onEnter(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {newPasswordMsg && newPasswordMsg.length > 0 ? (
                        <FormHelperText>{newPasswordMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      Re-type New Password
                      <TextField
                        type="password"
                        onChange={(event) =>
                          setRetypeNewPassword(event.target.value)
                        }
                        value={retypeNewPassword}
                        onKeyPress={(event) => {
                          onEnter(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {retypeNewPasswordMsg &&
                      retypeNewPasswordMsg.length > 0 ? (
                        <FormHelperText>{retypeNewPasswordMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                  </Grid>
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            CREATE MY PASSWORD
                          </a>
                        )}
                      </div>
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <Footer />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
