import React, { useState, useEffect } from "react";
import axios from "axios";
import Head from "next/head";
import Cookies from "js-cookie";
import { useRouter } from "next/router";
import { Box, Grid } from "@material-ui/core";
import StarIcon from "@mui/icons-material/Star";

// Components
import Header from "../../components/Header";
import Footer from "../../components/Footer";

// Mui Components
import { TextField } from "@material-ui/core";
import { styled } from "@mui/material/styles";
import LocalOfferIcon from "@mui/icons-material/LocalOffer";
import CircularProgress from "@mui/material/CircularProgress";
import CheckCircleIcon from "@mui/icons-material/CheckCircle";
import RegisterModal from "../../components/RegisterModal/RegisterModal";

const CssTextField = styled(TextField)({
  "& .MuiInputBase-root": {
    color: "black",
    fontSize: "14px",
  },
  "& .MuiOutlinedInput-root": {
    "& fieldset": {
      borderColor: "black",
    },
  },
});

export default function packages(props) {
  const [post, setPost] = useState(null);
  const [selectedIndex, setSelectedIndex] = useState(0);
  const [active, setActive] = useState(false);
  const [payNowWaitLoading, setPayNowWaitLoading] = useState(false);
  const [appliedPromoCode, setAppliedPromoCode] = useState("");
  const [code, setCode] = useState("");
  const [priceList, setPriceList] = useState([]);
  const [applyPromoCodeLoading, setApplyPromoCodeLoading] = useState(false);
  const [applyPromoCodeDone, setApplyPromoCodeDone] = useState(false);
  const [payableAmount, setPayableAmount] = useState(0);
  const [alertMessage, setAlertMessage] = useState("");
  const [severityAlert, setSeverityAlert] = useState("error");

  const [register, setRegister] = useState(false);
  const [status, setStatus] = useState("course");

  const router = useRouter();

  useEffect(() => {
    setPayNowWaitLoading(false);
    setApplyPromoCodeDone(false);
    setPriceList(props.data?.obj?.priceList);
    if (props.data && props.data.obj && props.data.obj.salePrice) {
      setPayableAmount(props.data.obj.salePrice);
      setCode("");
      setAppliedPromoCode("");
    }
  }, [props.data]);

  function applyPromoCode() {
    if (code) {
      setApplyPromoCodeLoading(true);
      getApiPromoCode(code);
    } else {
      setSeverityAlert("error");
      setAlertMessage("Enter promotional code");
      return false;
    }
  }

  const getApiPromoCode = async (code) => {
    let axiosHeader = {
      headers: {
        "Content-Type": "multipart/mixed",
      },
    };
    let apiURL =
      process.env.NEXT_PUBLIC_API_URL +
      "/web-verifypromocode-multiple-pricing?webUrl=" +
      process.env.NEXT_PUBLIC_WEB_URL_FOR_COURSES +
      "&promoCode=" +
      code +
      "&courseId=" +
      props.data.obj.courseId;

    axios.get(apiURL, axiosHeader).then((response) => {
      setPost(response.data);
      setApplyPromoCodeLoading(false);
      if (
        response &&
        response.data &&
        response.data.responseTxt === "success"
      ) {
        setApplyPromoCodeDone(true);
        setPayableAmount(response.data.amount);
        setAppliedPromoCode(code);
        setSeverityAlert("Success");
        setAlertMessage("Success! Choose a course above to purchase it");
        return false;
      } else if (
        response &&
        response.data &&
        response.data.responseTxt === "invalid"
      ) {
        setSeverityAlert("error");
        setAlertMessage("Promotional code is invalid.");
        return false;
      } else {
        setSeverityAlert("error");
        setAlertMessage("Something wrong with promotional code to apply.");
        return false;
      }
    });
  };

  if (!props.data) return null;
  function selectThisCourse(styp) {
    Cookies.set(
      "courseDetails",
      JSON.stringify({
        subscriptionType: styp,
        courseId: props.data.obj.courseId,
        courseName: props.data.obj.courseTitle,
        packId: props?.data?.obj?.priceList[selectedIndex]?.packId,
        promoCode: appliedPromoCode,
      })
    );
    // window.location.href = "/create-account-process";
    setRegister(true)
  }

  // const joinFree = () => {
  //   Cookies.set(
  //     "courseDetails",
  //     JSON.stringify({
  //       subscriptionType: "Free",
  //       courseId: props.data.obj.courseId,
  //       courseName: props.data.obj.courseTitle,
  //       packId: "",
  //       promoCode: "",
  //     })
  //   );
  //   window.location.href = "/create-account-process";
  // };

  useEffect(() => {
    if (register) {
      document.body.scrollTop = 0; // For Safari
      document.documentElement.scrollTop = 0; // For Chrome, Firefox, IE and Opera
      document.querySelector("body").style.height = "100vh";
      document.querySelector("body").style.overflow = "hidden";
    } else {
      document.querySelector("body").style = "";
    }
  }, [register]);


  return (
    <>
      <Head>
        <title>
          {props?.data?.obj?.courseTitle}: Buy Courses | EaseToLearn | India`s Largest Free Learning Platform
        </title>
        <meta
          name="description"
          content="Online Exam Preparation Site -Engine To Accelerate your Learning | EaseToLearn"
        />
        <meta
          name="keywords"
          content="Buy Online Tests for Recruitment Entrance Exams"
        />
        <link rel="canonical" href={`https://easetolearn.com${props?.url}`} />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />
        <section className="pkg-wrapper">
          {/* <img
            src="/packages.svg"
            className="packages-img"
            alt="ETL packages"
          /> */}
          <div style={{ width: "100%" }}>
            <h3>Available Plans</h3>

            <Box style={{ width: "100%", marginBottom: 20 }}>
              <Grid container className="innerOneBox">
                <Grid item xs={12}>
                  <div
                    style={{
                      width: "100%",
                      display: "flex",
                      alignItems: "center",
                      justifyContent: "center",
                      // padding: "20px",
                    }}
                  >
                    <div
                      style={{
                        width: "100%",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "space-evenly",
                        background: "rgba(0, 0, 0, 0.1)",
                        borderRadius: "10px",
                        border: "1px solid rgba(255, 255, 255, 0.4)",
                        padding: "20px",
                        color: "#000",
                        flexDirection: "column",
                      }}
                    >
                      <div
                        style={{
                          width: "100%",
                          display: "flex",
                          alignItems: "center",
                          justifyContent: "flex-start",
                        }}
                      >
                        <div style={{ flex: 0.6 }}></div>
                        <span
                          style={{
                            flex: 0.2,
                            fontWeight: "900",
                            fontFamily: "Gilroy-black",
                          }}
                        >
                          ACE
                        </span>
                        <span
                          style={{
                            flex: 0.2,
                            fontWeight: "900",
                            fontFamily: "Gilroy-black",
                          }}
                        >
                          PRO
                        </span>
                      </div>
                      <div
                        style={{
                          width: "100%",
                          display: "flex",
                          alignItems: "center",
                          justifyContent: "flex-start",
                          marginTop: "20px",
                          borderBottom: "1px solid rgba(255, 255, 255, 0.4)",
                          paddingBottom: "20px",
                        }}
                      >
                        <div style={{ flex: 0.6 }}>
                          <h3>My Study Room</h3>
                          {/* <p>Study Material</p> */}
                        </div>
                        <div
                          style={{
                            flex: 0.2,
                            fontSize: "18px",
                            paddingLeft: "21px",
                          }}
                        >
                          <span>&#10003;</span>
                        </div>
                        <div
                          style={{
                            flex: 0.2,
                            fontSize: "16px",
                            paddingLeft: "10px",
                          }}
                        >
                          <span>&#10060;</span>
                        </div>
                      </div>
                      <div
                        style={{
                          width: "100%",
                          display: "flex",
                          alignItems: "center",
                          justifyContent: "flex-start",
                          marginTop: "20px",
                        }}
                      >
                        <div style={{ flex: 0.6 }}>
                          <h3>My Exam Room</h3>
                          {/* <p>Topic Tests and Mock Tests</p> */}
                        </div>
                        <div
                          style={{
                            flex: 0.2,
                            fontSize: "18px",
                            paddingLeft: "21px",
                          }}
                        >
                          <span>&#10003;</span>
                        </div>
                        <div
                          style={{
                            flex: 0.2,
                            fontSize: "18px",
                            paddingLeft: "10px",
                          }}
                        >
                          <span>&#10003;</span>
                        </div>
                      </div>
                    </div>
                  </div>
                </Grid>
              </Grid>
            </Box>
            <div
              style={{
                display: "flex",
                alignItems: "center",
                justifyContent: "space-between",
                marginTop: 40,
              }}
            >
              {!applyPromoCodeDone ? (
                <>
                  <div style={{ flex: 0.48 }}>
                    {priceList
                      ?.slice(0, priceList?.length / 2)
                      ?.map((el, index) => {
                        return (
                          <div
                            className={`pkg-option ${
                              index === selectedIndex
                                ? "selectedIndex_packages"
                                : ""
                            }`}
                            onClick={() => {
                              setActive(!active ? !active : active);
                              setSelectedIndex(index);
                            }}
                          >
                            <span
                              style={{
                                position: "absolute",
                                top: "-20px",
                                left: 0,
                                marginBottom: "5px",
                                fontWeight: "900",
                              }}
                            >
                              {el?.packType}
                            </span>
                            <input
                              type="radio"
                              value={el?.title + index}
                              id={el?.title + index}
                              name="course"
                              checked={index === selectedIndex}
                            />

                            <div className="pkg-option-course">
                              <label
                                for={el?.title + index}
                                className="course-name validity_date"
                                style={{
                                  fontWeight:
                                    index === selectedIndex ? "700" : "500",
                                  fontFamily: "Gilroy-black",
                                }}
                              >
                                {el?.title}
                              </label>
                             {el?.discount ? <label
                                for={el?.title + index}
                                className="course-discount"
                              >
                                Save {el?.discount}%
                              </label> : <></>}
                            </div>

                            <div className="pkg-option-valid">
                              <label
                                for={el?.title + index}
                                className="packages_validity"
                              >
                                Valid till{" "}
                                <p className="validity_date validity_date_label">
                                  <strong>{el?.validityDate}</strong>
                                </p>
                              </label>
                            </div>

                            <div className="pkg-option-price">
                              <label
                                for={el?.title + index}
                                className="price-label"
                              >
                                ₹{el.salePrice}
                              </label>
                              {el?.discount ? <label
                                for={el?.title + index}
                                className="price-label-strike"
                              >
                                ₹{el.retailPrice}
                              </label> : <></>}
                            </div>
                          </div>
                        );
                      })}
                  </div>
                  <div style={{ flex: 0.48 }}>
                    {priceList
                      ?.slice(priceList?.length / 2)
                      ?.map((el, index) => {
                        return (
                          <div
                            className={`pkg-option ${
                              selectedIndex === index + priceList?.length / 2
                                ? "selectedIndex_packages"
                                : ""
                            }`}
                            onClick={() => {
                              setActive(!active ? !active : active);
                              setSelectedIndex(index + priceList?.length / 2);
                            }}
                          >
                            <span
                              style={{
                                position: "absolute",
                                top: "-20px",
                                left: 0,
                                marginBottom: "5px",
                                fontWeight: "900",
                              }}
                            >
                              {el?.packType}
                            </span>
                            <input
                              type="radio"
                              value={el?.title + index + priceList?.length / 2}
                              id={el?.title + index + priceList?.length / 2}
                              name="course"
                              checked={
                                selectedIndex === index + priceList?.length / 2
                              }
                            />

                            <div className="pkg-option-course">
                              <label
                                for={el?.title + index + priceList?.length / 2}
                                className="course-name validity_date"
                                style={{
                                  fontWeight:
                                    selectedIndex ===
                                    index + priceList?.length / 2
                                      ? "700"
                                      : "500",
                                  fontFamily: "Gilroy-black",
                                }}
                              >
                                {el?.title}
                              </label>
                              {el?.discount ? <label
                                for={el?.title + index + priceList?.length / 2}
                                className="course-discount"
                              >
                                Save {el?.discount}%
                              </label> : <></>}
                            </div>

                            <div className="pkg-option-valid">
                              <label
                                for={el?.title + index + priceList?.length / 2}
                                className="packages_validity"
                              >
                                Valid till{" "}
                                <p className="validity_date validity_date_label">
                                  <strong>{el?.validityDate}</strong>
                                </p>
                              </label>
                            </div>

                            <div className="pkg-option-price">
                              <label
                                for={el?.title + index + priceList?.length / 2}
                                className="price-label"
                              >
                                ₹{el.salePrice}
                              </label>
                             {el?.discount ? <label
                                for={el?.title + index + priceList?.length / 2}
                                className="price-label-strike"
                              >
                                ₹{el.retailPrice}
                              </label> : <></>}
                            </div>
                          </div>
                        );
                      })}
                  </div>
                </>
              ) : (
                <>
                  <div style={{ flex: 0.48 }}>
                    {post.priceList
                      ?.slice(0, post?.priceList?.length / 2)
                      .map((el, index) => {
                        return (
                          <div
                            className={`pkg-option ${
                              selectedIndex === index
                                ? "selectedIndex_packages"
                                : ""
                            }`}
                            onClick={() => {
                              setActive(!active ? !active : active);
                              setSelectedIndex(index);
                            }}
                          >
                            <span
                              style={{
                                position: "absolute",
                                top: "-20px",
                                left: 0,
                                marginBottom: "5px",
                                fontWeight: "900",
                              }}
                            >
                              {el?.packType}
                            </span>
                            <input
                              type="radio"
                              value={el.title + index}
                              id={el.title + index}
                              name="course"
                              checked={selectedIndex === index}
                              // onClick={() => setActive(!active ? !active : active)}
                            />
                            <div className="pkg-option-course">
                              <label
                                for={el.title + index}
                                className="course-name"
                              >
                                {el.title}
                              </label>
                              {el?.discount ? (
                                <label
                                  for={el.title + index}
                                  className="course-discount"
                                >
                                  Save {el.discount}%
                                </label>
                              ) : (
                                <></>
                              )}
                            </div>

                            <div className="pkg-option-valid">
                              <label
                                for={el.title + index}
                                className="course-name"
                              >
                                Valid till {el.validityDate}
                              </label>
                            </div>

                            <div className="pkg-option-price">
                              <label
                                for={el.title + index}
                                className="price-label"
                              >
                                ₹{el.salePrice}
                              </label>
                              {el?.discount ? (
                                <label
                                  for={el.title + index}
                                  className="price-label-strike"
                                >
                                  ₹{el.retailPrice}
                                </label>
                              ) : (
                                <></>
                              )}
                            </div>
                          </div>
                        );
                      })}
                  </div>
                  <div style={{ flex: 0.48 }}>
                    {post.priceList
                      ?.slice(post?.priceList?.length / 2)
                      .map((el, index) => {
                        return (
                          <div
                            className={`pkg-option ${
                              selectedIndex ===
                              index + post?.priceList?.length / 2
                                ? "selectedIndex_packages"
                                : ""
                            }`}
                            onClick={() => {
                              setActive(!active ? !active : active);
                              setSelectedIndex(
                                index + post?.priceList?.length / 2
                              );
                            }}
                          >
                            <span
                              style={{
                                position: "absolute",
                                top: "-20px",
                                left: 0,
                                marginBottom: "5px",
                                fontWeight: "900",
                              }}
                            >
                              {el?.packType}
                            </span>
                            <input
                              type="radio"
                              value={
                                el.title + index + post?.priceList?.length / 2
                              }
                              id={
                                el.title + index + post?.priceList?.length / 2
                              }
                              name="course"
                              checked={
                                selectedIndex ===
                                index + post?.priceList?.length / 2
                              }
                              // onClick={() => setActive(!active ? !active : active)}
                            />

                            <div className="pkg-option-course">
                              <label
                                for={
                                  el.title + index + post?.priceList?.length / 2
                                }
                                className="course-name"
                              >
                                {el.title}
                              </label>
                              {el?.discount ? (
                                <label
                                  for={
                                    el.title +
                                    index +
                                    post?.priceList?.length / 2
                                  }
                                  className="course-discount"
                                >
                                  Save {el.discount}%
                                </label>
                              ) : (
                                <></>
                              )}
                            </div>

                            <div className="pkg-option-valid">
                              <label
                                for={
                                  el.title + index + post?.priceList?.length / 2
                                }
                                className="course-name"
                              >
                                Valid till {el.validityDate}
                              </label>
                            </div>

                            <div className="pkg-option-price">
                              <label
                                for={
                                  el.title + index + post?.priceList?.length / 2
                                }
                                className="price-label"
                              >
                                ₹{el.salePrice}
                              </label>
                              {el?.discount ? (
                                <label
                                  for={
                                    el.title +
                                    index +
                                    post?.priceList?.length / 2
                                  }
                                  className="price-label-strike"
                                >
                                  ₹{el.retailPrice}
                                </label>
                              ) : (
                                <></>
                              )}
                            </div>
                          </div>
                        );
                      })}
                  </div>
                </>
              )}
            </div>
            <div className="payment-container">
              <div className="payment-container-left">
                {severityAlert === "error" ? (
                  <div style={{ color: "#FF0000", fontWeight: "bold" }}>
                    {alertMessage}
                  </div>
                ) : (
                  <div
                    style={{
                      color: "#000004",
                      fontWeight: "bold",
                      display: "flex",
                      justifyContent: "center",
                      columnGap: "8px",
                    }}
                  >
                    <CheckCircleIcon />
                    {alertMessage}
                  </div>
                )}
                {!applyPromoCodeDone ? (
                  <>
                    <div style={{display: "flex", alignItems: "center"}}>
                      <CssTextField
                        onChange={(event) => setCode(event.target.value)}
                        value={code}
                        size="small"
                        variant="outlined"
                        fullWidth
                        inputProps={{ maxLength: 50 }}
                        placeholder="Enter promo code"
                      />
                      <div className="applynow-box">
                        <div style={{ marginTop: 8 }}>
                          {props.data &&
                          props.data.obj &&
                          props.data.obj.promoList &&
                          props.data.obj.promoList.length > 0
                            ? props.data.obj.promoList.map((myPC, pcKey) => (
                                <span
                                  key={"pca" + pcKey}
                                  style={{ marginLeft: 5 }}
                                >
                                  <LocalOfferIcon
                                    style={{ color: "#000", fontSize: 10 }}
                                  />{" "}
                                  {myPC.description}
                                </span>
                              ))
                            : null}
                        </div>
                        <div item md={7} sm={7} xs={12}>
                          <div style={{ marginLeft: 5 }}>
                            {applyPromoCodeLoading ? (
                              <div className="mybttonpaynow">
                                <CircularProgress size={13} color={"inherit"} />{" "}
                                Wait...
                              </div>
                            ) : (
                              <button
                                onClick={() => {
                                  applyPromoCode();
                                }}
                                className="apply-button"
                              >
                                Apply
                              </button>
                            )}
                          </div>
                        </div>
                      </div>
                    </div>
                  </>
                ) : null}
              </div>
              <button onClick={() => selectThisCourse("Paid")}>Pay Now</button>
            </div>
          </div>
        </section>
        <Box style={{ margin: 20 }}>
          <Box className="featuresBox">
            <Grid container>
              <Grid item md={12} sm={12} xs={12}>
                <p className="headingTxt">Key Features</p>
                <ul>
                  <Grid container spacing={2}>
                    <Grid item md={6} sm={12} xs={12}>
                      <h2
                        className="color-dark"
                        style={{ textAlign: "center", marginBottom: 15 }}
                      >
                        MY Study Room™
                      </h2>
                      {props.data && props.data.obj && props.data.obj.studyRoom
                        ? props.data.obj.studyRoom
                            .split("\n")
                            .map((myRow, index) => (
                              <>
                                {myRow.indexOf("==") > -1 ? (
                                  <li key={index}>
                                    <div className="icon">
                                      <StarIcon style={{ fontSize: 13 }} />
                                    </div>
                                    <div className="txtsection">
                                      <h4>{myRow.split("==")[0]}</h4>
                                      <p>
                                        {myRow.split("==")[1].indexOf("##") >
                                        -1 ? (
                                          <ul className="featurepoints">
                                            {myRow
                                              .split("==")[1]
                                              .split("##")
                                              .map((myPoint, indexLi) => (
                                                <li key={"pt" + indexLi}>
                                                  - {myPoint}
                                                </li>
                                              ))}
                                          </ul>
                                        ) : (
                                          <>{myRow.split("==")[1]}</>
                                        )}
                                      </p>
                                    </div>
                                  </li>
                                ) : (
                                  <Grid container spacing={2} key={index}>
                                    <Grid item xs={12}>
                                      <li>
                                        <div className="icon">
                                          <StarIcon style={{ fontSize: 13 }} />
                                        </div>{" "}
                                        {myRow}
                                      </li>
                                    </Grid>
                                  </Grid>
                                )}
                              </>
                            ))
                        : null}
                    </Grid>

                    {props.data.obj?.priceType === 1 ? (
                      <Grid item md={6} sm={12} xs={12}>
                        <h2
                          className="color-dark"
                          style={{ textAlign: "center", marginBottom: 15 }}
                        >
                          MY Exam Room™
                        </h2>
                        {props.data && props.data.obj && props.data.obj.examPrep
                          ? props.data.obj.examPrep
                              .split("\n")
                              .map((myRow, index) => (
                                <>
                                  {myRow.indexOf("==") > -1 ? (
                                    <li key={index}>
                                      <div className="icon">
                                        <StarIcon style={{ fontSize: 13 }} />
                                      </div>
                                      <div className="txtsection">
                                        <h4>{myRow.split("==")[0]}</h4>
                                        <p>
                                          {myRow.split("==")[1].indexOf("##") >
                                          -1 ? (
                                            <ul className="featurepoints">
                                              {myRow
                                                .split("==")[1]
                                                .split("##")
                                                .map((myPoint, indexLi) => (
                                                  <li key={"pt" + indexLi}>
                                                    - {myPoint}
                                                  </li>
                                                ))}
                                            </ul>
                                          ) : (
                                            <>{myRow.split("==")[1]}</>
                                          )}
                                        </p>
                                      </div>
                                    </li>
                                  ) : (
                                    <Grid container spacing={2}>
                                      <Grid item xs={12}>
                                        <li>
                                          <div className="icon">
                                            <StarIcon
                                              style={{ fontSize: 13 }}
                                            />
                                          </div>{" "}
                                          {myRow}
                                        </li>
                                      </Grid>
                                    </Grid>
                                  )}
                                </>
                              ))
                          : null}
                      </Grid>
                    ) : (
                      <></>
                    )}
                  </Grid>
                </ul>
              </Grid>
            </Grid>
          </Box>
        </Box>
        <Footer />
      </main>
      {register ? (
        <RegisterModal
          status={status}
          setStatus={setStatus}
          registerPopup={register}
          setRegisterPopup={setRegister}
        />
      ) : (
        <></>
      )}
    </>
  );
}

export async function getServerSideProps(context) {
  const param = context.query || [];
  const res = await fetch(
    process.env.NEXT_PUBLIC_API_URL +
      "/website-course-details-mpricing?courseUrl=" +
      param.course
  );
  const data = await res.json();
  return { props: { data, url: context?.req?.url } };
}
