import React from "react";
import Head from "next/head";
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import CircularProgress from "@mui/material/CircularProgress";
import FormHelperText from "@mui/material/FormHelperText";
import Header from "../components/Header";
import Footer from "../components/Footer";
import Cookies from "js-cookie";
import axios from "axios";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  const classes = useStyles();
  const [waitBtn, setWaitBtn] = React.useState(false);

  const [firstName, setFirstName] = React.useState("");
  const [lastName, setLastName] = React.useState("");
  const [mobileNumber, setMobileNumber] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");
  const [schoolName, setSchoolName] = React.useState("");
  const [courseId, setCourseId] = React.useState(77);
  const [className, setClassName] = React.useState("Class XI or XII");
  const [token, setToken] = React.useState("");

  const [otpNumber, setOtpNumber] = React.useState("");
  const [otpVal, setOtpVal] = React.useState(false);
  const [otpValMsg, setOtpValMsg] = React.useState("Enter your OTP number");

  const [resendLoading, setResendLoading] = React.useState(false);
  const [resendValidationMsg, setResendValidationMsg] = React.useState("");

  ///alert("newaccount: "+newaccount)

  React.useEffect(() => {
    if (!newaccount) {
      window.location.href = "/create-account";
    } else if (newaccount) {
      const obj = JSON.parse(newaccount);
      setFirstName(obj.firstName);
      setLastName(obj.lastName);
      setMobileNumber(obj.mobile);
      setNewPassword(obj.newPassword);
      setSchoolName(obj.schoolName);
      setCourseId(obj.courseId);
      setClassName(obj.className);
      setToken(obj.token);
    }
  }, [newaccount]);

  function submit() {
    if (!otpNumber) {
      setOtpVal(true);
    } else {
      setOtpVal(false);
    }

    if (otpNumber) {
      setWaitBtn(true);

      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("studentName", firstName + " " + lastName);
      data.append("mobile", mobileNumber);
      data.append("newPassword", newPassword);
      data.append("schoolName", schoolName + " (" + className + ")");
      data.append("courseId", courseId); //CUET Course 89
      data.append("regDevice", "Desktop");
      data.append("token", token);
      data.append("otpNumber", otpNumber);

      axios
        .post(
          process.env.NEXT_PUBLIC_API_URL + "/newstudent-school-registration",
          data,
          axiosHeader
        )
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === "OK") {
            ///alert('OTP Page: '+response.data.token);
            ///Cookies.set('newaccount', JSON.stringify({firstName:firstName,lastName:lastName,mobile:mobileNumber,utype:utype}));
            //window.location.href='download';
            window.location.href =
              process.env.NEXT_PUBLIC_LOGIN_URL +
              "/logindirect?loginKey=" +
              response.data.token;
            return false;
          } else if (response.data.responseTxt === "InvalidOTP") {
            setOtpVal(true);
            setOtpValMsg("Invalid OTP");
            return false;
          } else {
            setOtpVal(true);
            setOtpValMsg("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setOtpVal(true);
          setOtpValMsg("" + error);
          return false;
        });
    }
  }

  function resendOtpApi() {
    try {
      setResendLoading(true);
      const formData = new FormData();
      formData.append("token", token);
      formData.append("mobile", mobileNumber);
      axios
        .post(process.env.NEXT_PUBLIC_API_URL + "/resend-otpmobilenumber", formData)
        .then((response) => {
          setResendLoading(false);
          if (response.data != null && response.data.responseTxt == "OK") {
            setResendValidationMsg("");
            setResendValidationMsg("OTP sent again");
          } else {
            setResendValidationMsg("Something went wrong, Try after sometime.");
          }
          ////console.log("AAA Response >> " + response.data);
        })
        .catch((error) => console.error(error));
    } catch (error) {
      console.error(error.response.data);
    }
  }

  function numberOnly(event) {
    if (!/[0-9]/.test(event.key)) {
      event.preventDefault();
    }
  }

  function maskNumber(number) {
    return number.substring(0, 2) + "*****" + number.substring(7, 10);
  }

  return (
    <>
      <Head>
        <title>Online Tests for Recruitment &amp; Entrance Exams</title>
        <meta
          name="description"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img src="/two.png" alt="ETL Image" />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>Verify your mobile</h1>
                <Grid className="frmbx">
                  <Grid item md={12} sm={12} xs={12}>
                    <div className="paybtnbox">
                      <span className="otp">
                        We have sent an OTP to your mobile number through SMS
                      </span>
                      <br />
                      {mobileNumber ? maskNumber(mobileNumber) : null}
                    </div>
                  </Grid>
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      OTP Number
                      <TextField
                        onChange={(event) => setOtpNumber(event.target.value)}
                        value={otpNumber}
                        onKeyPress={(event) => {
                          numberOnly(event);
                        }}
                        fullWidth
                        variant="outlined"
                        inputProps={{ maxLength: 6 }}
                      />
                      {otpVal ? (
                        <FormHelperText>{otpValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            SUBMIT OTP
                          </a>
                        )}
                      </div>
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {resendLoading ? (
                          <div style={{ textAlign: "center" }}>
                            <CircularProgress color="secondary" />
                            <br />
                            WAIT...
                          </div>
                        ) : resendValidationMsg &&
                          resendValidationMsg.indexOf("sent") > -1 ? (
                          <span
                            style={{ color: "#008000", fontWeight: "bold" }}
                          >
                            {resendValidationMsg}
                          </span>
                        ) : resendValidationMsg &&
                          resendValidationMsg.indexOf("wrong") > -1 ? (
                          <span
                            style={{ color: "#FF0000", fontWeight: "bold" }}
                          >
                            {resendValidationMsg}
                          </span>
                        ) : (
                          <div>
                            Did not receive OTP?{" "}
                            <a
                              href="javascript:;"
                              onClick={() => {
                                resendOtpApi();
                              }}
                            >
                              Resend OTP
                            </a>
                          </div>
                        )}
                        <br />
                        <br />
                        <br />
                        <a href="create-account">
                          Back to change mobile number
                        </a>
                      </div>
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <Footer />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
